# com.ultracart.admin.v2 - the C# library for the UltraCart Rest API V2

UltraCart REST API Version 2

This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- SDK version: 4.0.145
- Build package: org.openapitools.codegen.languages.CSharpClientCodegen
    For more information, please visit [http://www.ultracart.com](http://www.ultracart.com)

## Frameworks supported


- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

## Dependencies


- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:

```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

## Installation

Run the following command to generate the DLL

- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:

```csharp
using com.ultracart.admin.v2.Api;
using com.ultracart.admin.v2.Client;
using com.ultracart.admin.v2.Model;

```


## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out com.ultracart.admin.v2.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.


## Getting Started

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using com.ultracart.admin.v2.Api;
using com.ultracart.admin.v2.Client;
using com.ultracart.admin.v2.Model;

namespace Example
{
    public class Example
    {
        public static void Main()
        {

            Configuration.Default.BasePath = "https://secure.ultracart.com/rest/v2";
            // Configure OAuth2 access token for authorization: ultraCartOauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";
            // Configure API key authorization: ultraCartSimpleApiKey
            Configuration.Default.ApiKey.Add("x-ultracart-simple-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("x-ultracart-simple-key", "Bearer");

            var apiInstance = new AffiliateApi(Configuration.Default);
            var clickQuery = new AffiliateClickQuery(); // AffiliateClickQuery | Click query
            var limit = 10000;  // int? | The maximum number of records to return on this one API call. (Maximum 10000) (optional)  (default to 10000)
            var offset = 0;  // int? | Pagination of the record set.  Offset is a zero based index. (optional)  (default to 0)
            var expand = "expand_example";  // string | The object expansion to perform on the result.  Only option is link. (optional) 

            try
            {
                // Retrieve clicks
                AffiliateClicksResponse result = apiInstance.GetClicksByQuery(clickQuery, limit, offset, expand);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling AffiliateApi.GetClicksByQuery: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }

        }
    }
}
```

## Documentation for API Endpoints

All URIs are relative to *https://secure.ultracart.com/rest/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AffiliateApi* | [**GetClicksByQuery**](docs/AffiliateApi.md#getclicksbyquery) | **POST** /affiliate/clicks/query | Retrieve clicks
*AffiliateApi* | [**GetLedgersByQuery**](docs/AffiliateApi.md#getledgersbyquery) | **POST** /affiliate/ledgers/query | Retrieve ledger entries
*AutoOrderApi* | [**GetAutoOrder**](docs/AutoOrderApi.md#getautoorder) | **GET** /auto_order/auto_orders/{auto_order_oid} | Retrieve an auto order by oid
*AutoOrderApi* | [**GetAutoOrderByCode**](docs/AutoOrderApi.md#getautoorderbycode) | **GET** /auto_order/auto_orders/code/{auto_order_code} | Retrieve an auto order by code
*AutoOrderApi* | [**GetAutoOrderByReferenceOrderId**](docs/AutoOrderApi.md#getautoorderbyreferenceorderid) | **GET** /auto_order/auto_orders/reference_order_id/{reference_order_id} | Retrieve an auto order by order id
*AutoOrderApi* | [**GetAutoOrders**](docs/AutoOrderApi.md#getautoorders) | **GET** /auto_order/auto_orders | Retrieve auto orders
*AutoOrderApi* | [**GetAutoOrdersBatch**](docs/AutoOrderApi.md#getautoordersbatch) | **POST** /auto_order/auto_orders/batch | Retrieve auto order batch
*AutoOrderApi* | [**GetAutoOrdersByQuery**](docs/AutoOrderApi.md#getautoordersbyquery) | **POST** /auto_order/auto_orders/query | Retrieve auto orders by query
*AutoOrderApi* | [**UpdateAutoOrder**](docs/AutoOrderApi.md#updateautoorder) | **PUT** /auto_order/auto_orders/{auto_order_oid} | Update an auto order
*AutoOrderApi* | [**UpdateAutoOrdersBatch**](docs/AutoOrderApi.md#updateautoordersbatch) | **PUT** /auto_order/auto_orders/batch | Update multiple auto orders
*ChannelPartnerApi* | [**CancelOrderByChannelPartnerOrderId**](docs/ChannelPartnerApi.md#cancelorderbychannelpartnerorderid) | **DELETE** /channel_partner/cancel/by_channel_partner_order_id/{order_id} | Cancel channel partner order by channel partner order id
*ChannelPartnerApi* | [**CancelOrderByUltraCartOrderId**](docs/ChannelPartnerApi.md#cancelorderbyultracartorderid) | **DELETE** /channel_partner/cancel/by_ultracart_order_id/{order_id} | Cancel channel partner order by UltraCart order id
*ChannelPartnerApi* | [**DeleteChannelPartnerShipToPreference**](docs/ChannelPartnerApi.md#deletechannelpartnershiptopreference) | **DELETE** /channel_partner/channel_partners/{channel_partner_oid}/ship_to_preferences/{channel_partner_ship_to_preference_oid} | Delete a ship to preference record for the channel partner.
*ChannelPartnerApi* | [**EstimateShippingForChannelPartnerOrder**](docs/ChannelPartnerApi.md#estimateshippingforchannelpartnerorder) | **POST** /channel_partner/estimate_shipping | Estimate shipping for channel partner order
*ChannelPartnerApi* | [**EstimateTaxForChannelPartnerOrder**](docs/ChannelPartnerApi.md#estimatetaxforchannelpartnerorder) | **POST** /channel_partner/estimate_tax | Estimate tax for channel partner order
*ChannelPartnerApi* | [**GetChannelPartnerShipToPreference**](docs/ChannelPartnerApi.md#getchannelpartnershiptopreference) | **GET** /channel_partner/channel_partners/{channel_partner_oid}/ship_to_preferences/{channel_partner_ship_to_preference_oid} | Retrieve the ship to preference associated with the channel partner and the specific id.
*ChannelPartnerApi* | [**GetChannelPartnerShipToPreferences**](docs/ChannelPartnerApi.md#getchannelpartnershiptopreferences) | **GET** /channel_partner/channel_partners/{channel_partner_oid}/ship_to_preferences | Retrieve the ship to preferences associated with the channel partner.
*ChannelPartnerApi* | [**GetChannelPartners**](docs/ChannelPartnerApi.md#getchannelpartners) | **GET** /channel_partner/channel_partners | Retrieve the channel partners configured on the account.
*ChannelPartnerApi* | [**ImportChannelPartnerOrder**](docs/ChannelPartnerApi.md#importchannelpartnerorder) | **POST** /channel_partner/import | Insert channel partner order
*ChannelPartnerApi* | [**InsertChannelPartnerShipToPreference**](docs/ChannelPartnerApi.md#insertchannelpartnershiptopreference) | **POST** /channel_partner/channel_partners/{channel_partner_oid}/ship_to_preferences | Insert a ship to preference record for the channel partner.
*ChannelPartnerApi* | [**UpdateChannelPartnerShipToPreference**](docs/ChannelPartnerApi.md#updatechannelpartnershiptopreference) | **PUT** /channel_partner/channel_partners/{channel_partner_oid}/ship_to_preferences/{channel_partner_ship_to_preference_oid} | Update a ship to preference record for the channel partner.
*ChargebackApi* | [**DeleteChargeback**](docs/ChargebackApi.md#deletechargeback) | **DELETE** /chargeback/chargebacks/{chargeback_dispute_oid} | Delete a chargeback
*ChargebackApi* | [**GetChargebackDispute**](docs/ChargebackApi.md#getchargebackdispute) | **GET** /chargeback/chargebacks/{chargeback_dispute_oid} | Retrieve a chargeback
*ChargebackApi* | [**GetChargebackDisputes**](docs/ChargebackApi.md#getchargebackdisputes) | **GET** /chargeback/chargebacks | Retrieve chargebacks
*ChargebackApi* | [**InsertChargeback**](docs/ChargebackApi.md#insertchargeback) | **POST** /chargeback/chargebacks | Insert a chargeback
*ChargebackApi* | [**UpdateChargeback**](docs/ChargebackApi.md#updatechargeback) | **PUT** /chargeback/chargebacks/{chargeback_dispute_oid} | Update a chargeback
*CheckoutApi* | [**CityState**](docs/CheckoutApi.md#citystate) | **POST** /checkout/city_state | City/State for Zip
*CheckoutApi* | [**FinalizeOrder**](docs/CheckoutApi.md#finalizeorder) | **POST** /checkout/cart/finalizeOrder | Finalize Order
*CheckoutApi* | [**GetAffirmCheckout**](docs/CheckoutApi.md#getaffirmcheckout) | **GET** /checkout/cart/{cart_id}/affirmCheckout | Get affirm checkout (by cart id)
*CheckoutApi* | [**GetAllowedCountries**](docs/CheckoutApi.md#getallowedcountries) | **POST** /checkout/allowedCountries | Allowed countries
*CheckoutApi* | [**GetCart**](docs/CheckoutApi.md#getcart) | **GET** /checkout/cart | Get cart
*CheckoutApi* | [**GetCartByCartId**](docs/CheckoutApi.md#getcartbycartid) | **GET** /checkout/cart/{cart_id} | Get cart (by cart id)
*CheckoutApi* | [**GetCartByReturnCode**](docs/CheckoutApi.md#getcartbyreturncode) | **GET** /checkout/return/{return_code} | Get cart (by return code)
*CheckoutApi* | [**GetCartByReturnToken**](docs/CheckoutApi.md#getcartbyreturntoken) | **GET** /checkout/return_token | Get cart (by return token)
*CheckoutApi* | [**GetStateProvincesForCountry**](docs/CheckoutApi.md#getstateprovincesforcountry) | **POST** /checkout/stateProvincesForCountry/{country_code} | Get state/province list for a country code
*CheckoutApi* | [**HandoffCart**](docs/CheckoutApi.md#handoffcart) | **POST** /checkout/cart/handoff | Handoff cart
*CheckoutApi* | [**Login**](docs/CheckoutApi.md#login) | **POST** /checkout/cart/profile/login | Profile login
*CheckoutApi* | [**Logout**](docs/CheckoutApi.md#logout) | **POST** /checkout/cart/profile/logout | Profile logout
*CheckoutApi* | [**Register**](docs/CheckoutApi.md#register) | **POST** /checkout/cart/profile/register | Profile registration
*CheckoutApi* | [**RegisterAffiliateClick**](docs/CheckoutApi.md#registeraffiliateclick) | **POST** /checkout/affiliateClick/register | Register affiliate click
*CheckoutApi* | [**RelatedItemsForCart**](docs/CheckoutApi.md#relateditemsforcart) | **POST** /checkout/related_items | Related items
*CheckoutApi* | [**RelatedItemsForItem**](docs/CheckoutApi.md#relateditemsforitem) | **POST** /checkout/relatedItems/{item_id} | Related items (specific item)
*CheckoutApi* | [**SetupBrowserKey**](docs/CheckoutApi.md#setupbrowserkey) | **PUT** /checkout/browser_key | Setup Browser Application
*CheckoutApi* | [**UpdateCart**](docs/CheckoutApi.md#updatecart) | **PUT** /checkout/cart | Update cart
*CheckoutApi* | [**ValidateCart**](docs/CheckoutApi.md#validatecart) | **POST** /checkout/cart/validate | Validate
*ConversationApi* | [**DeleteConversationCannedMessage**](docs/ConversationApi.md#deleteconversationcannedmessage) | **DELETE** /conversation/canned_messages/{conversation_canned_message_oid} | Delete a conversation canned message
*ConversationApi* | [**DeleteDepartment**](docs/ConversationApi.md#deletedepartment) | **DELETE** /conversation/departments/{conversation_department_oid} | Delete a conversation department
*ConversationApi* | [**DeleteEngagement**](docs/ConversationApi.md#deleteengagement) | **DELETE** /conversation/engagements/{conversation_engagement_oid} | Delete a conversation engagement
*ConversationApi* | [**GetAgentKeepAlive**](docs/ConversationApi.md#getagentkeepalive) | **GET** /conversation/agent/keepalive | Agent keep alive
*ConversationApi* | [**GetAgentProfile**](docs/ConversationApi.md#getagentprofile) | **GET** /conversation/agent/profile | Get agent profile
*ConversationApi* | [**GetAgentWebsocketAuthorization**](docs/ConversationApi.md#getagentwebsocketauthorization) | **PUT** /conversation/agent/auth | Get agent websocket authorization
*ConversationApi* | [**GetConversation**](docs/ConversationApi.md#getconversation) | **GET** /conversation/conversations/{conversation_uuid} | Retrieve a conversation
*ConversationApi* | [**GetConversationCannedMessages**](docs/ConversationApi.md#getconversationcannedmessages) | **GET** /conversation/canned_messages | Retrieve a list of canned messages ordered by short_code
*ConversationApi* | [**GetConversationContext**](docs/ConversationApi.md#getconversationcontext) | **PUT** /conversation/conversations/{conversation_uuid}/context | Get a webchat conversation context
*ConversationApi* | [**GetConversationDepartmentMemberList**](docs/ConversationApi.md#getconversationdepartmentmemberlist) | **GET** /conversation/department_members | Retrieve a list of possible department members
*ConversationApi* | [**GetConversationDepartments**](docs/ConversationApi.md#getconversationdepartments) | **GET** /conversation/departments | Retrieve a list of departments ordered by name
*ConversationApi* | [**GetConversationEngagement**](docs/ConversationApi.md#getconversationengagement) | **GET** /conversation/engagements/{conversation_engagement_oid} | Retrieve an engagement
*ConversationApi* | [**GetConversationEngagements**](docs/ConversationApi.md#getconversationengagements) | **GET** /conversation/engagements | Retrieve a list of engagements ordered by name
*ConversationApi* | [**GetConversationMessages**](docs/ConversationApi.md#getconversationmessages) | **GET** /conversation/conversations/{conversation_uuid}/messages/{since} | Retrieve conversation messages
*ConversationApi* | [**GetConversationMultimediaUploadUrl**](docs/ConversationApi.md#getconversationmultimediauploadurl) | **GET** /conversation/upload_url/{extension} | Get a presigned conersation multimedia upload URL
*ConversationApi* | [**GetConversationPermissions**](docs/ConversationApi.md#getconversationpermissions) | **GET** /conversation/permissions | Retrieve conversation permissions
*ConversationApi* | [**GetConversationWebchatQueueStatuses**](docs/ConversationApi.md#getconversationwebchatqueuestatuses) | **GET** /conversation/conversations/queues/statuses | Retrieve a conversation webchat queue statuses
*ConversationApi* | [**GetConversations**](docs/ConversationApi.md#getconversations) | **GET** /conversation/conversations | Retrieve a list of conversation summaries newest to oldest
*ConversationApi* | [**GetConversationsAutocomplete**](docs/ConversationApi.md#getconversationsautocomplete) | **POST** /conversation/conversations/autocomplete | Retrieve a list of matching terms for a search field
*ConversationApi* | [**GetConversationsSearch**](docs/ConversationApi.md#getconversationssearch) | **POST** /conversation/conversations/search | Search conversations
*ConversationApi* | [**GetLocationsForEngagement**](docs/ConversationApi.md#getlocationsforengagement) | **POST** /conversation/locations | Get location data for engagement configuration
*ConversationApi* | [**InsertConversationCannedMessage**](docs/ConversationApi.md#insertconversationcannedmessage) | **POST** /conversation/canned_messages | Insert a canned message
*ConversationApi* | [**InsertConversationDepartment**](docs/ConversationApi.md#insertconversationdepartment) | **POST** /conversation/departments | Insert a department
*ConversationApi* | [**InsertConversationEngagement**](docs/ConversationApi.md#insertconversationengagement) | **POST** /conversation/engagements | Insert a engagement
*ConversationApi* | [**JoinConversation**](docs/ConversationApi.md#joinconversation) | **PUT** /conversation/conversations/{conversation_uuid}/join | Join a conversation
*ConversationApi* | [**LeaveConversation**](docs/ConversationApi.md#leaveconversation) | **DELETE** /conversation/conversations/{conversation_uuid}/leave | Leave a conversation
*ConversationApi* | [**MarkReadConversation**](docs/ConversationApi.md#markreadconversation) | **PUT** /conversation/conversations/{conversation_uuid}/markread | Mark a conversation as read
*ConversationApi* | [**SearchConversationCannedMessages**](docs/ConversationApi.md#searchconversationcannedmessages) | **POST** /conversation/canned_messages/search | Search for canned messages by short_code
*ConversationApi* | [**SmsUnsubscribeConversation**](docs/ConversationApi.md#smsunsubscribeconversation) | **PUT** /conversation/conversations/{conversation_uuid}/sms_unsubscribe | Unsubscribe any SMS participants in this conversation
*ConversationApi* | [**StartConversation**](docs/ConversationApi.md#startconversation) | **PUT** /conversation/conversations | Start a conversation
*ConversationApi* | [**UpdateAgentProfile**](docs/ConversationApi.md#updateagentprofile) | **PUT** /conversation/agent/profile | Update agent profile
*ConversationApi* | [**UpdateConversationCannedMessage**](docs/ConversationApi.md#updateconversationcannedmessage) | **PUT** /conversation/canned_messages/{conversation_canned_message_oid} | Update a canned message
*ConversationApi* | [**UpdateConversationDepartment**](docs/ConversationApi.md#updateconversationdepartment) | **PUT** /conversation/departments/{conversation_department_oid} | Update a department
*ConversationApi* | [**UpdateConversationEngagement**](docs/ConversationApi.md#updateconversationengagement) | **PUT** /conversation/engagements/{conversation_engagement_oid} | Update a engagement
*ConversationApi* | [**UpdateConversationWebchatQueueStatus**](docs/ConversationApi.md#updateconversationwebchatqueuestatus) | **PUT** /conversation/conversations/queues/{queue_name}/status | Update status within the queue
*CouponApi* | [**DeleteCoupon**](docs/CouponApi.md#deletecoupon) | **DELETE** /coupon/coupons/{coupon_oid} | Delete a coupon
*CouponApi* | [**DeleteCouponsByCode**](docs/CouponApi.md#deletecouponsbycode) | **DELETE** /coupon/coupons/by_code | Deletes multiple coupons
*CouponApi* | [**DeleteCouponsByOid**](docs/CouponApi.md#deletecouponsbyoid) | **DELETE** /coupon/coupons/by_oid | Deletes multiple coupons
*CouponApi* | [**DoesCouponCodeExist**](docs/CouponApi.md#doescouponcodeexist) | **GET** /coupon/coupons/merchant_code/{merchant_code}/exists | Determines if a coupon merchant code already exists
*CouponApi* | [**GenerateCouponCodes**](docs/CouponApi.md#generatecouponcodes) | **POST** /coupon/coupons/{coupon_oid}/generate_codes | Generates one time codes for a coupon
*CouponApi* | [**GenerateOneTimeCodesByMerchantCode**](docs/CouponApi.md#generateonetimecodesbymerchantcode) | **POST** /coupon/coupons/merchant_code/{merchant_code}/generate_codes | Generates one time codes by merchant code
*CouponApi* | [**GetAutoApply**](docs/CouponApi.md#getautoapply) | **GET** /coupon/auto_apply | Retrieve auto apply rules and conditions
*CouponApi* | [**GetCoupon**](docs/CouponApi.md#getcoupon) | **GET** /coupon/coupons/{coupon_oid} | Retrieve a coupon
*CouponApi* | [**GetCouponByMerchantCode**](docs/CouponApi.md#getcouponbymerchantcode) | **GET** /coupon/coupons/merchant_code/{merchant_code} | Retrieve a coupon by merchant code
*CouponApi* | [**GetCoupons**](docs/CouponApi.md#getcoupons) | **GET** /coupon/coupons | Retrieve coupons
*CouponApi* | [**GetCouponsByQuery**](docs/CouponApi.md#getcouponsbyquery) | **POST** /coupon/coupons/query | Retrieve coupons by query
*CouponApi* | [**GetEditorValues**](docs/CouponApi.md#geteditorvalues) | **GET** /coupon/editor_values | Retrieve values needed for a coupon editor
*CouponApi* | [**InsertCoupon**](docs/CouponApi.md#insertcoupon) | **POST** /coupon/coupons | Insert a coupon
*CouponApi* | [**InsertCoupons**](docs/CouponApi.md#insertcoupons) | **POST** /coupon/coupons/batch | Insert multiple coupons
*CouponApi* | [**SearchItems**](docs/CouponApi.md#searchitems) | **GET** /coupon/searchItems | Searches for items to display within a coupon editor and assign to coupons
*CouponApi* | [**UpdateAutoApply**](docs/CouponApi.md#updateautoapply) | **POST** /coupon/auto_apply | Update auto apply rules and conditions
*CouponApi* | [**UpdateCoupon**](docs/CouponApi.md#updatecoupon) | **PUT** /coupon/coupons/{coupon_oid} | Update a coupon
*CouponApi* | [**UpdateCoupons**](docs/CouponApi.md#updatecoupons) | **PUT** /coupon/coupons/batch | Update multiple coupons
*CouponApi* | [**UploadCouponCodes**](docs/CouponApi.md#uploadcouponcodes) | **POST** /coupon/coupons/{coupon_oid}/upload_codes | Upload one-time codes for a coupon
*CustomerApi* | [**AddCustomerStoreCredit**](docs/CustomerApi.md#addcustomerstorecredit) | **POST** /customer/customers/{customer_profile_oid}/store_credit | Adds store credit to a customer
*CustomerApi* | [**AdjustInternalCertificate**](docs/CustomerApi.md#adjustinternalcertificate) | **POST** /customer/customers/{customer_profile_oid}/adjust_cashback_balance | Updates the cashback balance for a customer by updating the internal gift certificate used, creating the gift certificate if needed.
*CustomerApi* | [**DeleteCustomer**](docs/CustomerApi.md#deletecustomer) | **DELETE** /customer/customers/{customer_profile_oid} | Delete a customer
*CustomerApi* | [**GetCustomer**](docs/CustomerApi.md#getcustomer) | **GET** /customer/customers/{customer_profile_oid} | Retrieve a customer
*CustomerApi* | [**GetCustomerByEmail**](docs/CustomerApi.md#getcustomerbyemail) | **GET** /customer/customers/by_email/{email} | Retrieve a customer by Email
*CustomerApi* | [**GetCustomerEditorValues**](docs/CustomerApi.md#getcustomereditorvalues) | **GET** /customer/editor_values | Retrieve values needed for a customer profile editor
*CustomerApi* | [**GetCustomerEmailLists**](docs/CustomerApi.md#getcustomeremaillists) | **GET** /customer/email_lists | Retrieve all email lists across all storefronts
*CustomerApi* | [**GetCustomerStoreCredit**](docs/CustomerApi.md#getcustomerstorecredit) | **GET** /customer/customers/{customer_profile_oid}/store_credit | Retrieve the customer store credit accumulated through loyalty programs
*CustomerApi* | [**GetCustomers**](docs/CustomerApi.md#getcustomers) | **GET** /customer/customers | Retrieve customers
*CustomerApi* | [**GetCustomersByQuery**](docs/CustomerApi.md#getcustomersbyquery) | **POST** /customer/customers/query | Retrieve customers by query
*CustomerApi* | [**GetCustomersForDataTables**](docs/CustomerApi.md#getcustomersfordatatables) | **POST** /customer/customers/dataTables | Retrieve customers for DataTables plugin
*CustomerApi* | [**GetEmailVerificationToken**](docs/CustomerApi.md#getemailverificationtoken) | **POST** /customer/customers/email_verify/get_token | Create a token that can be used to verify a customer email address
*CustomerApi* | [**GetMagicLink**](docs/CustomerApi.md#getmagiclink) | **PUT** /customer/customers/{customer_profile_oid}/magic_link/{storefront_host_name} | getMagicLink
*CustomerApi* | [**InsertCustomer**](docs/CustomerApi.md#insertcustomer) | **POST** /customer/customers | Insert a customer
*CustomerApi* | [**MergeCustomer**](docs/CustomerApi.md#mergecustomer) | **PUT** /customer/customers/{customer_profile_oid}/merge | Merge customer into this customer
*CustomerApi* | [**SearchCustomerProfileValues**](docs/CustomerApi.md#searchcustomerprofilevalues) | **POST** /customer/search | Searches for all matching values (using POST)
*CustomerApi* | [**UpdateCustomer**](docs/CustomerApi.md#updatecustomer) | **PUT** /customer/customers/{customer_profile_oid} | Update a customer
*CustomerApi* | [**UpdateCustomerEmailLists**](docs/CustomerApi.md#updatecustomeremaillists) | **POST** /customer/customers/{customer_profile_oid}/email_lists | Update email list subscriptions for a customer
*CustomerApi* | [**ValidateEmailVerificationToken**](docs/CustomerApi.md#validateemailverificationtoken) | **POST** /customer/customers/email_verify/validate_token | Validate a token that can be used to verify a customer email address
*DatawarehouseApi* | [**DeleteReport**](docs/DatawarehouseApi.md#deletereport) | **DELETE** /datawarehouse/reports/{report_oid} | Delete a report
*DatawarehouseApi* | [**DryRunReportQueries**](docs/DatawarehouseApi.md#dryrunreportqueries) | **PUT** /datawarehouse/reports/dryrun | Dry run the report queries
*DatawarehouseApi* | [**ExecuteReportQueries**](docs/DatawarehouseApi.md#executereportqueries) | **PUT** /datawarehouse/reports/execute | Execute the report queries
*DatawarehouseApi* | [**GetReport**](docs/DatawarehouseApi.md#getreport) | **GET** /datawarehouse/reports/{report_oid} | Get a report
*DatawarehouseApi* | [**GetReportDataSet**](docs/DatawarehouseApi.md#getreportdataset) | **GET** /datawarehouse/reports/dataset/{dataset_uuid} | Get a report data set
*DatawarehouseApi* | [**GetReportDataSetPage**](docs/DatawarehouseApi.md#getreportdatasetpage) | **GET** /datawarehouse/reports/dataset/{dataset_uuid}/pages/{page_number} | Get a report data set page
*DatawarehouseApi* | [**GetReportWebsocketAuthorization**](docs/DatawarehouseApi.md#getreportwebsocketauthorization) | **PUT** /datawarehouse/reports/auth | Get report websocket authorization
*DatawarehouseApi* | [**GetReports**](docs/DatawarehouseApi.md#getreports) | **GET** /datawarehouse/reports | Get list of reports available
*DatawarehouseApi* | [**InsertReport**](docs/DatawarehouseApi.md#insertreport) | **POST** /datawarehouse/reports | Create a report
*DatawarehouseApi* | [**UpdateReport**](docs/DatawarehouseApi.md#updatereport) | **PUT** /datawarehouse/reports/{report_oid} | Update a report
*FulfillmentApi* | [**AcknowledgeOrders**](docs/FulfillmentApi.md#acknowledgeorders) | **PUT** /fulfillment/distribution_centers/{distribution_center_code}/acknowledgements | Acknowledge receipt of orders.
*FulfillmentApi* | [**GeneratePackingSlip**](docs/FulfillmentApi.md#generatepackingslip) | **GET** /fulfillment/distribution_centers/{distribution_center_code}/orders/{order_id} | Generate a packing slip for this order for the given distribution center.
*FulfillmentApi* | [**GetDistributionCenterOrders**](docs/FulfillmentApi.md#getdistributioncenterorders) | **GET** /fulfillment/distribution_centers/{distribution_center_code}/orders | Retrieve orders queued up for this distribution center.
*FulfillmentApi* | [**GetDistributionCenters**](docs/FulfillmentApi.md#getdistributioncenters) | **GET** /fulfillment/distribution_centers | Retrieve distribution centers
*FulfillmentApi* | [**ShipOrders**](docs/FulfillmentApi.md#shiporders) | **POST** /fulfillment/distribution_centers/{distribution_center_code}/shipments | Mark orders as shipped
*FulfillmentApi* | [**UpdateInventory**](docs/FulfillmentApi.md#updateinventory) | **POST** /fulfillment/distribution_centers/{distribution_center_code}/inventory | Update inventory
*GiftCertificateApi* | [**AddGiftCertificateLedgerEntry**](docs/GiftCertificateApi.md#addgiftcertificateledgerentry) | **POST** /gift_certificate/gift_certificates/{gift_certificate_oid}/ledger_entry | Add a gift certificate ledger entry
*GiftCertificateApi* | [**CreateGiftCertificate**](docs/GiftCertificateApi.md#creategiftcertificate) | **POST** /gift_certificate/gift_certificates | Create a gift certificate
*GiftCertificateApi* | [**DeleteGiftCertificate**](docs/GiftCertificateApi.md#deletegiftcertificate) | **DELETE** /gift_certificate/gift_certificates/{gift_certificate_oid} | Delete a gift certificate
*GiftCertificateApi* | [**GetGiftCertificateByCode**](docs/GiftCertificateApi.md#getgiftcertificatebycode) | **POST** /gift_certificate/gift_certificates/by_code/{code} | Retrieve gift certificate by code
*GiftCertificateApi* | [**GetGiftCertificateByOid**](docs/GiftCertificateApi.md#getgiftcertificatebyoid) | **POST** /gift_certificate/gift_certificates/{gift_certificate_oid} | Retrieve gift certificate by oid
*GiftCertificateApi* | [**GetGiftCertificatesByEmail**](docs/GiftCertificateApi.md#getgiftcertificatesbyemail) | **POST** /gift_certificate/gift_certificates/by_email/{email} | Retrieve gift certificate by email
*GiftCertificateApi* | [**GetGiftCertificatesByQuery**](docs/GiftCertificateApi.md#getgiftcertificatesbyquery) | **POST** /gift_certificate/gift_certificates/query | Retrieve gift certificates by query
*GiftCertificateApi* | [**UpdateGiftCertificate**](docs/GiftCertificateApi.md#updategiftcertificate) | **PUT** /gift_certificate/gift_certificates/{gift_certificate_oid} | Update a gift certificate
*IntegrationLogApi* | [**GetIntegrationLog**](docs/IntegrationLogApi.md#getintegrationlog) | **GET** /integration_log/query/{pk}/{sk} | Retrieve an integration log
*IntegrationLogApi* | [**GetIntegrationLogFile**](docs/IntegrationLogApi.md#getintegrationlogfile) | **GET** /integration_log/query/{pk}/{sk}/{uuid} | Retrieve an integration log file
*IntegrationLogApi* | [**GetIntegrationLogFilePdf**](docs/IntegrationLogApi.md#getintegrationlogfilepdf) | **GET** /integration_log/query/{pk}/{sk}/{uuid}/pdf | Retrieve an integration log file converted to PDF
*IntegrationLogApi* | [**GetIntegrationLogSummariesQuery**](docs/IntegrationLogApi.md#getintegrationlogsummariesquery) | **POST** /integration_log/summary/query | Retrieve integration log summaries
*IntegrationLogApi* | [**GetIntegrationLogsQuery**](docs/IntegrationLogApi.md#getintegrationlogsquery) | **POST** /integration_log/query | Retrieve integration logs
*ItemApi* | [**DeleteDigitalItem**](docs/ItemApi.md#deletedigitalitem) | **DELETE** /item/digital_library/{digital_item_oid} | Delete a digital item, which is a file within the digital library, not an actual merchant item
*ItemApi* | [**DeleteItem**](docs/ItemApi.md#deleteitem) | **DELETE** /item/items/{merchant_item_oid} | Delete an item
*ItemApi* | [**GetDigitalItem**](docs/ItemApi.md#getdigitalitem) | **GET** /item/digital_library/{digital_item_oid} | Retrieve a digital item from the digital library, which are digital files that may be attached to normal items
*ItemApi* | [**GetDigitalItems**](docs/ItemApi.md#getdigitalitems) | **GET** /item/digital_library | Retrieve digital items from the digital library which are digital files that may be attached to normal items
*ItemApi* | [**GetDigitalItemsByExternalId**](docs/ItemApi.md#getdigitalitemsbyexternalid) | **GET** /item/digital_library/by_external/{external_id} | Retrieves digital items from the digital library (which are digital files that may be attached to normal items) that having a matching external id
*ItemApi* | [**GetItem**](docs/ItemApi.md#getitem) | **GET** /item/items/{merchant_item_oid} | Retrieve an item
*ItemApi* | [**GetItemByMerchantItemId**](docs/ItemApi.md#getitembymerchantitemid) | **GET** /item/items/merchant_item_id/{merchant_item_id} | Retrieve an item by item id
*ItemApi* | [**GetItems**](docs/ItemApi.md#getitems) | **GET** /item/items | Retrieve items
*ItemApi* | [**GetPricingTiers**](docs/ItemApi.md#getpricingtiers) | **GET** /item/pricing_tiers | Retrieve pricing tiers
*ItemApi* | [**GetUnassociatedDigitalItems**](docs/ItemApi.md#getunassociateddigitalitems) | **GET** /item/digital_library/unassociated | Retrieve digital items from the digital library (which are digital files that may be attached to normal items) not yet associated with actual items
*ItemApi* | [**InsertDigitalItem**](docs/ItemApi.md#insertdigitalitem) | **POST** /item/digital_library | Create a file within the digital library
*ItemApi* | [**InsertItem**](docs/ItemApi.md#insertitem) | **POST** /item/items | Create an item
*ItemApi* | [**UpdateDigitalItem**](docs/ItemApi.md#updatedigitalitem) | **PUT** /item/digital_library/{digital_item_oid} | Updates a file within the digital library
*ItemApi* | [**UpdateItem**](docs/ItemApi.md#updateitem) | **PUT** /item/items/{merchant_item_oid} | Update an item
*ItemApi* | [**UpdateItems**](docs/ItemApi.md#updateitems) | **PUT** /item/items/batch | Update multiple items
*ItemApi* | [**UploadTemporaryMultimedia**](docs/ItemApi.md#uploadtemporarymultimedia) | **POST** /item/temp_multimedia | Upload an image to the temporary multimedia.
*OauthApi* | [**OauthAccessToken**](docs/OauthApi.md#oauthaccesstoken) | **POST** /oauth/token | Exchange authorization code for access token.
*OauthApi* | [**OauthRevoke**](docs/OauthApi.md#oauthrevoke) | **POST** /oauth/revoke | Revoke this OAuth application.
*OrderApi* | [**AdjustOrderTotal**](docs/OrderApi.md#adjustordertotal) | **POST** /order/orders/{order_id}/adjust_order_total/{desired_total} | Adjusts an order total
*OrderApi* | [**CancelOrder**](docs/OrderApi.md#cancelorder) | **POST** /order/orders/{order_id}/cancel | Cancel an order
*OrderApi* | [**DeleteOrder**](docs/OrderApi.md#deleteorder) | **DELETE** /order/orders/{order_id} | Delete an order
*OrderApi* | [**DuplicateOrder**](docs/OrderApi.md#duplicateorder) | **POST** /order/orders/{order_id}/duplicate | Duplicate an order
*OrderApi* | [**Format**](docs/OrderApi.md#format) | **POST** /order/orders/{order_id}/format | Format order
*OrderApi* | [**GenerateInvoice**](docs/OrderApi.md#generateinvoice) | **GET** /order/orders/{order_id}/invoice | Generate an invoice for this order.
*OrderApi* | [**GenerateOrderToken**](docs/OrderApi.md#generateordertoken) | **GET** /order/orders/token/{order_id} | Generate an order token for a given order id
*OrderApi* | [**GeneratePackingSlipAllDC**](docs/OrderApi.md#generatepackingslipalldc) | **GET** /order/orders/{order_id}/packing_slip | Generate a packing slip for this order across all distribution centers.
*OrderApi* | [**GeneratePackingSlipSpecificDC**](docs/OrderApi.md#generatepackingslipspecificdc) | **GET** /order/orders/{order_id}/packing_slip/{distribution_center_code} | Generate a packing slip for this order for the given distribution center.
*OrderApi* | [**GetAccountsReceivableRetryConfig**](docs/OrderApi.md#getaccountsreceivableretryconfig) | **GET** /order/accountsReceivableRetryConfig | Retrieve A/R Retry Configuration
*OrderApi* | [**GetAccountsReceivableRetryStats**](docs/OrderApi.md#getaccountsreceivableretrystats) | **GET** /order/accountsReceivableRetryConfig/stats | Retrieve A/R Retry Statistics
*OrderApi* | [**GetOrder**](docs/OrderApi.md#getorder) | **GET** /order/orders/{order_id} | Retrieve an order
*OrderApi* | [**GetOrderByToken**](docs/OrderApi.md#getorderbytoken) | **POST** /order/orders/token | Retrieve an order using a token
*OrderApi* | [**GetOrderEdiDocuments**](docs/OrderApi.md#getorderedidocuments) | **GET** /order/orders/{order_id}/edi | Retrieve EDI documents associated with this order.
*OrderApi* | [**GetOrders**](docs/OrderApi.md#getorders) | **GET** /order/orders | Retrieve orders
*OrderApi* | [**GetOrdersBatch**](docs/OrderApi.md#getordersbatch) | **POST** /order/orders/batch | Retrieve order batch
*OrderApi* | [**GetOrdersByQuery**](docs/OrderApi.md#getordersbyquery) | **POST** /order/orders/query | Retrieve orders by query
*OrderApi* | [**InsertOrder**](docs/OrderApi.md#insertorder) | **POST** /order/orders | Insert an order
*OrderApi* | [**IsRefundableOrder**](docs/OrderApi.md#isrefundableorder) | **GET** /order/orders/{order_id}/refundable | Determine if an order can be refunded
*OrderApi* | [**ProcessPayment**](docs/OrderApi.md#processpayment) | **POST** /order/orders/{order_id}/process_payment | Process payment
*OrderApi* | [**RefundOrder**](docs/OrderApi.md#refundorder) | **PUT** /order/orders/{order_id}/refund | Refund an order
*OrderApi* | [**Replacement**](docs/OrderApi.md#replacement) | **POST** /order/orders/{order_id}/replacement | Replacement order
*OrderApi* | [**ResendReceipt**](docs/OrderApi.md#resendreceipt) | **POST** /order/orders/{order_id}/resend_receipt | Resend receipt
*OrderApi* | [**ResendShipmentConfirmation**](docs/OrderApi.md#resendshipmentconfirmation) | **POST** /order/orders/{order_id}/resend_shipment_confirmation | Resend shipment confirmation
*OrderApi* | [**UpdateAccountsReceivableRetryConfig**](docs/OrderApi.md#updateaccountsreceivableretryconfig) | **POST** /order/accountsReceivableRetryConfig | Update A/R Retry Configuration
*OrderApi* | [**UpdateOrder**](docs/OrderApi.md#updateorder) | **PUT** /order/orders/{order_id} | Update an order
*SsoApi* | [**GetSsoSessionUser**](docs/SsoApi.md#getssosessionuser) | **GET** /sso/session/user | Get single sign on session user
*SsoApi* | [**SsoAuthorize**](docs/SsoApi.md#ssoauthorize) | **PUT** /sso/authorize | Authorize a single sign on session
*SsoApi* | [**SsoSessionRevoke**](docs/SsoApi.md#ssosessionrevoke) | **DELETE** /sso/session/revoke | Revoke single sign on session
*SsoApi* | [**SsoToken**](docs/SsoApi.md#ssotoken) | **PUT** /sso/token | Exchange a single sign on code for a simple key token
*StorefrontApi* | [**AddToLibrary**](docs/StorefrontApi.md#addtolibrary) | **POST** /storefront/code_library | Add to library
*StorefrontApi* | [**ApplyToStoreFront**](docs/StorefrontApi.md#applytostorefront) | **POST** /storefront/code_library/apply | Apply library item to storefront.
*StorefrontApi* | [**ArchiveEmailList**](docs/StorefrontApi.md#archiveemaillist) | **POST** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/archive | Archive email list
*StorefrontApi* | [**ArchiveEmailSegment**](docs/StorefrontApi.md#archiveemailsegment) | **POST** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/archive | Archive email segment
*StorefrontApi* | [**BackPopulateEmailFlow**](docs/StorefrontApi.md#backpopulateemailflow) | **POST** /storefront/{storefront_oid}/email/flows/{email_flow_uuid}/backfill | Back populate email flow
*StorefrontApi* | [**CheckDownloadEmailSegment**](docs/StorefrontApi.md#checkdownloademailsegment) | **POST** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/downloadPrepare/{email_segment_rebuild_uuid} | Check download of email segment
*StorefrontApi* | [**CloneEmailCampaign**](docs/StorefrontApi.md#cloneemailcampaign) | **POST** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/clone | Clone email campaign
*StorefrontApi* | [**CloneEmailFlow**](docs/StorefrontApi.md#cloneemailflow) | **POST** /storefront/{storefront_oid}/email/flows/{email_flow_uuid}/clone | Clone email flow
*StorefrontApi* | [**CreateEmailSendingDomain**](docs/StorefrontApi.md#createemailsendingdomain) | **POST** /storefront/email/sending_domains/{domain}/create | Create email campaign
*StorefrontApi* | [**CreateEmailSendingDomain2**](docs/StorefrontApi.md#createemailsendingdomain2) | **POST** /storefront/email/sending_domains | Create email sending domain for various providers
*StorefrontApi* | [**CreateFsDirectory**](docs/StorefrontApi.md#createfsdirectory) | **POST** /storefront/{id}/fs/dir | Create file manager directory
*StorefrontApi* | [**CreateTwilioAccount**](docs/StorefrontApi.md#createtwilioaccount) | **POST** /storefront/twilio/accounts | Create Twilio account
*StorefrontApi* | [**DeleteEmailCampaignFolder**](docs/StorefrontApi.md#deleteemailcampaignfolder) | **DELETE** /storefront/{storefront_oid}/email/campaign_folders/{email_campaign_folder_uuid} | Delete email campaignFolder
*StorefrontApi* | [**DeleteEmailCommseqStat**](docs/StorefrontApi.md#deleteemailcommseqstat) | **DELETE** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/stat | Delete communication sequence stats
*StorefrontApi* | [**DeleteEmailEmail**](docs/StorefrontApi.md#deleteemailemail) | **DELETE** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Delete email email
*StorefrontApi* | [**DeleteEmailFlowFolder**](docs/StorefrontApi.md#deleteemailflowfolder) | **DELETE** /storefront/{storefront_oid}/email/flow_folders/{email_flow_folder_uuid} | Delete email flowFolder
*StorefrontApi* | [**DeleteEmailListCustomer**](docs/StorefrontApi.md#deleteemaillistcustomer) | **DELETE** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/customers/{email_customer_uuid} | Delete email list customer
*StorefrontApi* | [**DeleteEmailListSegmentFolder**](docs/StorefrontApi.md#deleteemaillistsegmentfolder) | **DELETE** /storefront/{storefront_oid}/email/list_segment_folders/{email_list_segment_folder_uuid} | Delete email ListSegmentFolder
*StorefrontApi* | [**DeleteEmailPostcard**](docs/StorefrontApi.md#deleteemailpostcard) | **DELETE** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid} | Delete email postcard
*StorefrontApi* | [**DeleteEmailSendingDomain**](docs/StorefrontApi.md#deleteemailsendingdomain) | **DELETE** /storefront/email/sending_domains/{domain} | delete email campaign
*StorefrontApi* | [**DeleteExperiment**](docs/StorefrontApi.md#deleteexperiment) | **DELETE** /storefront/{storefront_oid}/experiments/{storefront_experiment_oid} | Delete experiment
*StorefrontApi* | [**DeleteFsFile**](docs/StorefrontApi.md#deletefsfile) | **DELETE** /storefront/{id}/fs/file | Delete file manager directory
*StorefrontApi* | [**DeleteHeatmap**](docs/StorefrontApi.md#deleteheatmap) | **DELETE** /storefront/{storefront_oid}/screen_recordings/heatmap | Delete screen recording heatmap
*StorefrontApi* | [**DeleteLibraryItem**](docs/StorefrontApi.md#deletelibraryitem) | **DELETE** /storefront/code_library/{library_item_oid} | Delete library item
*StorefrontApi* | [**DeleteLibraryItemPublishedVersions**](docs/StorefrontApi.md#deletelibraryitempublishedversions) | **DELETE** /storefront/code_library/{library_item_oid}/published_versions | Delete all published versions for a library item, including anything in review.
*StorefrontApi* | [**DeleteScreenRecordingSegment**](docs/StorefrontApi.md#deletescreenrecordingsegment) | **DELETE** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid} | Delete screen recording segment
*StorefrontApi* | [**DeleteTwilioAccount**](docs/StorefrontApi.md#deletetwilioaccount) | **DELETE** /storefront/twilio/accounts/{esp_twilio_uuid} | delete Twilio account
*StorefrontApi* | [**DuplicateLibraryItem**](docs/StorefrontApi.md#duplicatelibraryitem) | **POST** /storefront/code_library/{library_item_oid}/duplicate | Duplicate library item.
*StorefrontApi* | [**FavoriteScreenRecording**](docs/StorefrontApi.md#favoritescreenrecording) | **POST** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/favorite | Update favorite flag on screen recording
*StorefrontApi* | [**GeocodeAddress**](docs/StorefrontApi.md#geocodeaddress) | **POST** /storefront/{storefront_oid}/email/geocode | Obtain lat/long for an address
*StorefrontApi* | [**GetCountries**](docs/StorefrontApi.md#getcountries) | **GET** /storefront/{storefront_oid}/email/countries | Get countries
*StorefrontApi* | [**GetEditorToken**](docs/StorefrontApi.md#geteditortoken) | **GET** /storefront/{storefront_oid}/editor_token | Gets editor token
*StorefrontApi* | [**GetEmailBaseTemplates**](docs/StorefrontApi.md#getemailbasetemplates) | **GET** /storefront/{storefront_oid}/email/baseTemplates | Get email communication base templates
*StorefrontApi* | [**GetEmailCampaign**](docs/StorefrontApi.md#getemailcampaign) | **GET** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid} | Get email campaign
*StorefrontApi* | [**GetEmailCampaignFolder**](docs/StorefrontApi.md#getemailcampaignfolder) | **GET** /storefront/{storefront_oid}/email/campaign_folders/{email_campaign_folder_uuid} | Get email campaign folder
*StorefrontApi* | [**GetEmailCampaignFolders**](docs/StorefrontApi.md#getemailcampaignfolders) | **GET** /storefront/{storefront_oid}/email/campaign_folders | Get email campaign folders
*StorefrontApi* | [**GetEmailCampaignScreenshots**](docs/StorefrontApi.md#getemailcampaignscreenshots) | **GET** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/screenshots | Get email campaign screenshots
*StorefrontApi* | [**GetEmailCampaigns**](docs/StorefrontApi.md#getemailcampaigns) | **GET** /storefront/{storefront_oid}/email/campaigns | Get email campaigns
*StorefrontApi* | [**GetEmailCampaignsWithStats**](docs/StorefrontApi.md#getemailcampaignswithstats) | **GET** /storefront/{storefront_oid}/email/campaignsWithStats/{stat_days} | Get email campaigns with stats
*StorefrontApi* | [**GetEmailCommseq**](docs/StorefrontApi.md#getemailcommseq) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid} | Get email commseq
*StorefrontApi* | [**GetEmailCommseqEmailStats**](docs/StorefrontApi.md#getemailcommseqemailstats) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/emailStats | Get email communication sequence emails stats
*StorefrontApi* | [**GetEmailCommseqPostcardStats**](docs/StorefrontApi.md#getemailcommseqpostcardstats) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/postcardStats | Get email communication sequence postcard stats
*StorefrontApi* | [**GetEmailCommseqPostcardTracking**](docs/StorefrontApi.md#getemailcommseqpostcardtracking) | **GET** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid}/tracking | Get email communication postcard tracking
*StorefrontApi* | [**GetEmailCommseqStatOverall**](docs/StorefrontApi.md#getemailcommseqstatoverall) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/stat | Get communication sequence stats overall
*StorefrontApi* | [**GetEmailCommseqStepStats**](docs/StorefrontApi.md#getemailcommseqstepstats) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/stepStats | Get email communication sequence step stats
*StorefrontApi* | [**GetEmailCommseqStepWaiting**](docs/StorefrontApi.md#getemailcommseqstepwaiting) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/waiting | Get email communication sequence customers waiting at each requested step
*StorefrontApi* | [**GetEmailCommseqWebhookEditorValues**](docs/StorefrontApi.md#getemailcommseqwebhookeditorvalues) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/webhookEditorValues | Get email webhook editor values
*StorefrontApi* | [**GetEmailCommseqs**](docs/StorefrontApi.md#getemailcommseqs) | **GET** /storefront/{storefront_oid}/email/commseqs | Get email commseqs
*StorefrontApi* | [**GetEmailCustomerEditorUrl**](docs/StorefrontApi.md#getemailcustomereditorurl) | **GET** /storefront/{storefront_oid}/email/customers/{email_customer_uuid}/editor_url | Get customers editor URL
*StorefrontApi* | [**GetEmailCustomers**](docs/StorefrontApi.md#getemailcustomers) | **GET** /storefront/{storefront_oid}/email/customers | Get email customers
*StorefrontApi* | [**GetEmailDashboardActivity**](docs/StorefrontApi.md#getemaildashboardactivity) | **GET** /storefront/{storefront_oid}/email/dashboard_activity | Get email dashboard activity
*StorefrontApi* | [**GetEmailDashboardStats**](docs/StorefrontApi.md#getemaildashboardstats) | **GET** /storefront/{storefront_oid}/email/dashboard_stats | Get dashboard stats
*StorefrontApi* | [**GetEmailDispatchLogs**](docs/StorefrontApi.md#getemaildispatchlogs) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/steps/{commseq_step_uuid}/logs | Get email dispatch logs
*StorefrontApi* | [**GetEmailEmail**](docs/StorefrontApi.md#getemailemail) | **GET** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Get email email
*StorefrontApi* | [**GetEmailEmailClicks**](docs/StorefrontApi.md#getemailemailclicks) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/steps/{commseq_step_uuid}/emails/{commseq_email_uuid}/clicks | Get email email clicks
*StorefrontApi* | [**GetEmailEmailCustomerEditorUrl**](docs/StorefrontApi.md#getemailemailcustomereditorurl) | **GET** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid}/orders/{order_id}/editor_url | Get email order customer editor url
*StorefrontApi* | [**GetEmailEmailOrders**](docs/StorefrontApi.md#getemailemailorders) | **GET** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/steps/{commseq_step_uuid}/emails/{commseq_email_uuid}/orders | Get email email orders
*StorefrontApi* | [**GetEmailEmails**](docs/StorefrontApi.md#getemailemails) | **GET** /storefront/{storefront_oid}/email/emails | Get email emails
*StorefrontApi* | [**GetEmailEmailsMultiple**](docs/StorefrontApi.md#getemailemailsmultiple) | **POST** /storefront/{storefront_oid}/email/emails/multiple | Get email emails multiple
*StorefrontApi* | [**GetEmailFlow**](docs/StorefrontApi.md#getemailflow) | **GET** /storefront/{storefront_oid}/email/flows/{email_flow_uuid} | Get email flow
*StorefrontApi* | [**GetEmailFlowFolder**](docs/StorefrontApi.md#getemailflowfolder) | **GET** /storefront/{storefront_oid}/email/flow_folders/{email_flow_folder_uuid} | Get email flow folder
*StorefrontApi* | [**GetEmailFlowFolders**](docs/StorefrontApi.md#getemailflowfolders) | **GET** /storefront/{storefront_oid}/email/flow_folders | Get email flow folders
*StorefrontApi* | [**GetEmailFlowScreenshots**](docs/StorefrontApi.md#getemailflowscreenshots) | **GET** /storefront/{storefront_oid}/email/flows/{email_flow_uuid}/screenshots | Get email flow screenshots
*StorefrontApi* | [**GetEmailFlows**](docs/StorefrontApi.md#getemailflows) | **GET** /storefront/{storefront_oid}/email/flows | Get email flows
*StorefrontApi* | [**GetEmailGlobalSettings**](docs/StorefrontApi.md#getemailglobalsettings) | **GET** /storefront/email/global_settings | Get email globalsettings
*StorefrontApi* | [**GetEmailList**](docs/StorefrontApi.md#getemaillist) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid} | Get email list
*StorefrontApi* | [**GetEmailListCustomerEditorUrl**](docs/StorefrontApi.md#getemaillistcustomereditorurl) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/customers/{email_customer_uuid}/editor_url | Get email list customer editor url
*StorefrontApi* | [**GetEmailListCustomers**](docs/StorefrontApi.md#getemaillistcustomers) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/customers | Get email list customers
*StorefrontApi* | [**GetEmailListSegmentFolder**](docs/StorefrontApi.md#getemaillistsegmentfolder) | **GET** /storefront/{storefront_oid}/email/list_segment_folders/{email_list_segment_folder_uuid} | Get email campaign folder
*StorefrontApi* | [**GetEmailListSegmentFolders**](docs/StorefrontApi.md#getemaillistsegmentfolders) | **GET** /storefront/{storefront_oid}/email/list_segment_folders | Get email campaign folders
*StorefrontApi* | [**GetEmailLists**](docs/StorefrontApi.md#getemaillists) | **GET** /storefront/{storefront_oid}/email/lists | Get email lists
*StorefrontApi* | [**GetEmailPerformance**](docs/StorefrontApi.md#getemailperformance) | **GET** /storefront/{storefront_oid}/email/performance | Get email performance
*StorefrontApi* | [**GetEmailPlan**](docs/StorefrontApi.md#getemailplan) | **GET** /storefront/{storefront_oid}/email/plan | Get email plan
*StorefrontApi* | [**GetEmailPostcard**](docs/StorefrontApi.md#getemailpostcard) | **GET** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid} | Get email postcard
*StorefrontApi* | [**GetEmailPostcards**](docs/StorefrontApi.md#getemailpostcards) | **GET** /storefront/{storefront_oid}/email/postcards | Get email postcards
*StorefrontApi* | [**GetEmailPostcardsMultiple**](docs/StorefrontApi.md#getemailpostcardsmultiple) | **POST** /storefront/{storefront_oid}/email/postcards/multiple | Get email postcards multiple
*StorefrontApi* | [**GetEmailSegment**](docs/StorefrontApi.md#getemailsegment) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid} | Get email segment
*StorefrontApi* | [**GetEmailSegmentCustomerEditorUrl**](docs/StorefrontApi.md#getemailsegmentcustomereditorurl) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/customers/{email_customer_uuid}/editor_url | Get email segment customers editor URL
*StorefrontApi* | [**GetEmailSegmentCustomers**](docs/StorefrontApi.md#getemailsegmentcustomers) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/customers | Get email segment customers
*StorefrontApi* | [**GetEmailSegments**](docs/StorefrontApi.md#getemailsegments) | **GET** /storefront/{storefront_oid}/email/segments | Get email segments
*StorefrontApi* | [**GetEmailSendingDomain**](docs/StorefrontApi.md#getemailsendingdomain) | **GET** /storefront/email/sending_domain/{domain} | Get email sending domain
*StorefrontApi* | [**GetEmailSendingDomainStatus**](docs/StorefrontApi.md#getemailsendingdomainstatus) | **POST** /storefront/email/sending_domains/{domain}/status | Get email sending domain status
*StorefrontApi* | [**GetEmailSendingDomains**](docs/StorefrontApi.md#getemailsendingdomains) | **GET** /storefront/email/sending_domains | Get email sending domains
*StorefrontApi* | [**GetEmailSettings**](docs/StorefrontApi.md#getemailsettings) | **GET** /storefront/{storefront_oid}/email/settings | Get email settings
*StorefrontApi* | [**GetEmailTemplate**](docs/StorefrontApi.md#getemailtemplate) | **GET** /storefront/{storefront_oid}/email/templates/{email_template_oid} | Get email template
*StorefrontApi* | [**GetEmailTemplates**](docs/StorefrontApi.md#getemailtemplates) | **GET** /storefront/{storefront_oid}/email/templates | Get email templates
*StorefrontApi* | [**GetEmailThirdPartyProviders**](docs/StorefrontApi.md#getemailthirdpartyproviders) | **GET** /storefront/{storefront_oid}/email/third_party_providers | Get a list of third party email providers
*StorefrontApi* | [**GetExperiments**](docs/StorefrontApi.md#getexperiments) | **GET** /storefront/{storefront_oid}/experiments | Get experiments
*StorefrontApi* | [**GetFsDirectory**](docs/StorefrontApi.md#getfsdirectory) | **GET** /storefront/{id}/fs/dir | Get file manager directory
*StorefrontApi* | [**GetHeatmap**](docs/StorefrontApi.md#getheatmap) | **POST** /storefront/{storefront_oid}/screen_recordings/heatmap | Get screen recording heatmap
*StorefrontApi* | [**GetHeatmapIndex**](docs/StorefrontApi.md#getheatmapindex) | **POST** /storefront/{storefront_oid}/screen_recordings/heatmap/index | Get screen recording heatmap index
*StorefrontApi* | [**GetHistogramPropertyNames**](docs/StorefrontApi.md#gethistogrampropertynames) | **GET** /storefront/{storefront_oid}/email/histogram/property_names | Get histogram property names
*StorefrontApi* | [**GetHistogramPropertyValues**](docs/StorefrontApi.md#gethistogrampropertyvalues) | **GET** /storefront/{storefront_oid}/email/histogram/property_values | Get histogram property values
*StorefrontApi* | [**GetLibraryFilterValues**](docs/StorefrontApi.md#getlibraryfiltervalues) | **GET** /storefront/code_library/filter_values | Get library values used to populate drop down boxes for filtering.
*StorefrontApi* | [**GetLibraryItem**](docs/StorefrontApi.md#getlibraryitem) | **GET** /storefront/code_library/{library_item_oid} | Get library item.
*StorefrontApi* | [**GetLibraryItemPublishedVersions**](docs/StorefrontApi.md#getlibraryitempublishedversions) | **GET** /storefront/code_library/{library_item_oid}/published_versions | Get all published versions for a library item.
*StorefrontApi* | [**GetScreenRecording**](docs/StorefrontApi.md#getscreenrecording) | **GET** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid} | Get screen recording
*StorefrontApi* | [**GetScreenRecordingPageViewData**](docs/StorefrontApi.md#getscreenrecordingpageviewdata) | **GET** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/page_view_data/{screen_recording_page_view_uuid} | Get screen recording page view data
*StorefrontApi* | [**GetScreenRecordingSegment**](docs/StorefrontApi.md#getscreenrecordingsegment) | **GET** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid} | Get screen recording segment
*StorefrontApi* | [**GetScreenRecordingSegments**](docs/StorefrontApi.md#getscreenrecordingsegments) | **GET** /storefront/{storefront_oid}/screen_recordings/segments | Get screen recording segments
*StorefrontApi* | [**GetScreenRecordingSettings**](docs/StorefrontApi.md#getscreenrecordingsettings) | **GET** /storefront/{storefront_oid}/screen_recordings/settings | Get screen recording settings
*StorefrontApi* | [**GetScreenRecordingTags**](docs/StorefrontApi.md#getscreenrecordingtags) | **POST** /storefront/{storefront_oid}/screen_recordings/tags | Get tags used by screen recording
*StorefrontApi* | [**GetScreenRecordingsByQuery**](docs/StorefrontApi.md#getscreenrecordingsbyquery) | **POST** /storefront/{storefront_oid}/screen_recordings/query | Query screen recordings
*StorefrontApi* | [**GetScreenRecordingsBySegment**](docs/StorefrontApi.md#getscreenrecordingsbysegment) | **POST** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid}/query | Get screen recordings by segment
*StorefrontApi* | [**GetStoreFrontPricingTiers**](docs/StorefrontApi.md#getstorefrontpricingtiers) | **GET** /storefront/pricing_tiers | Retrieve pricing tiers
*StorefrontApi* | [**GetStoreFronts**](docs/StorefrontApi.md#getstorefronts) | **GET** /storefront | Get storefronts (internal use only for security reasons)
*StorefrontApi* | [**GetThumbnailParameters**](docs/StorefrontApi.md#getthumbnailparameters) | **POST** /storefront/thumbnailParameters | Get thumbnail parameters
*StorefrontApi* | [**GetTransactionEmail**](docs/StorefrontApi.md#gettransactionemail) | **GET** /storefront/{storefront_oid}/transaction_email/list/{email_id} | Gets a transaction email object
*StorefrontApi* | [**GetTransactionEmailList**](docs/StorefrontApi.md#gettransactionemaillist) | **GET** /storefront/{storefront_oid}/transaction_email/list | Gets a list of transaction email names
*StorefrontApi* | [**GetTransactionEmailScreenshots**](docs/StorefrontApi.md#gettransactionemailscreenshots) | **GET** /storefront/{storefront_oid}/transaction_email/list/{email_id}/screenshots | Get transactional email screenshots
*StorefrontApi* | [**GetTwilioAccount**](docs/StorefrontApi.md#gettwilioaccount) | **GET** /storefront/twilio/accounts/{esp_twilio_uuid} | Get Twilio account
*StorefrontApi* | [**GetTwilioAccounts**](docs/StorefrontApi.md#gettwilioaccounts) | **GET** /storefront/twilio/accounts | Get all Twilio accounts
*StorefrontApi* | [**GetUploadFsFileUrl**](docs/StorefrontApi.md#getuploadfsfileurl) | **GET** /storefront/{id}/fs/upload_url/{extension} | Retrieves a S3 url where a file may be uploaded. Once uploaded, use uploadFsFile to trigger the server into reading the S3 bucket and retrieving the file.
*StorefrontApi* | [**GlobalUnsubscribe**](docs/StorefrontApi.md#globalunsubscribe) | **POST** /storefront/{storefront_oid}/email/globalUnsubscribe | Globally unsubscribe a customer
*StorefrontApi* | [**ImportEmailThirdPartyProviderList**](docs/StorefrontApi.md#importemailthirdpartyproviderlist) | **POST** /storefront/{storefront_oid}/email/third_party_providers/import | Import a third party provider list
*StorefrontApi* | [**InsertEmailCampaign**](docs/StorefrontApi.md#insertemailcampaign) | **POST** /storefront/{storefront_oid}/email/campaigns | Insert email campaign
*StorefrontApi* | [**InsertEmailCampaignFolder**](docs/StorefrontApi.md#insertemailcampaignfolder) | **POST** /storefront/{storefront_oid}/email/campaign_folders | Insert email campaign folder
*StorefrontApi* | [**InsertEmailCommseq**](docs/StorefrontApi.md#insertemailcommseq) | **POST** /storefront/{storefront_oid}/email/commseqs | Insert email commseq
*StorefrontApi* | [**InsertEmailEmail**](docs/StorefrontApi.md#insertemailemail) | **POST** /storefront/{storefront_oid}/email/emails | Insert email email
*StorefrontApi* | [**InsertEmailFlow**](docs/StorefrontApi.md#insertemailflow) | **POST** /storefront/{storefront_oid}/email/flows | Insert email flow
*StorefrontApi* | [**InsertEmailFlowFolder**](docs/StorefrontApi.md#insertemailflowfolder) | **POST** /storefront/{storefront_oid}/email/flow_folders | Insert email flow folder
*StorefrontApi* | [**InsertEmailList**](docs/StorefrontApi.md#insertemaillist) | **POST** /storefront/{storefront_oid}/email/lists | Insert email list
*StorefrontApi* | [**InsertEmailListSegmentFolder**](docs/StorefrontApi.md#insertemaillistsegmentfolder) | **POST** /storefront/{storefront_oid}/email/list_segment_folders | Insert email campaign folder
*StorefrontApi* | [**InsertEmailPostcard**](docs/StorefrontApi.md#insertemailpostcard) | **POST** /storefront/{storefront_oid}/email/postcards | Insert email postcard
*StorefrontApi* | [**InsertEmailSegment**](docs/StorefrontApi.md#insertemailsegment) | **POST** /storefront/{storefront_oid}/email/segments | Insert email segment
*StorefrontApi* | [**InsertScreenRecordingSegment**](docs/StorefrontApi.md#insertscreenrecordingsegment) | **POST** /storefront/{storefront_oid}/screen_recordings/segments | Insert screen recording segment
*StorefrontApi* | [**PrepareDownloadEmailSegment**](docs/StorefrontApi.md#preparedownloademailsegment) | **POST** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/downloadPrepare | Prepare download of email segment
*StorefrontApi* | [**PublishLibraryItem**](docs/StorefrontApi.md#publishlibraryitem) | **POST** /storefront/code_library/{library_item_oid}/publish | Publish library item.
*StorefrontApi* | [**PurchaseLibraryItem**](docs/StorefrontApi.md#purchaselibraryitem) | **POST** /storefront/code_library/{library_item_oid}/purchase | Purchase public library item, which creates a copy of the item in your personal code library
*StorefrontApi* | [**ReleaseEmailCommseqStepWaiting**](docs/StorefrontApi.md#releaseemailcommseqstepwaiting) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/waiting/{commseq_step_uuid} | Release email communication sequence customers waiting at the specified step
*StorefrontApi* | [**Review**](docs/StorefrontApi.md#review) | **POST** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid}/review | Request a review of an email
*StorefrontApi* | [**Search**](docs/StorefrontApi.md#search) | **GET** /storefront/search | Searches for all matching values
*StorefrontApi* | [**Search2**](docs/StorefrontApi.md#search2) | **POST** /storefront/search | Searches for all matching values (using POST)
*StorefrontApi* | [**SearchEmailListCustomers**](docs/StorefrontApi.md#searchemaillistcustomers) | **GET** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/search | Search email list customers
*StorefrontApi* | [**SearchEmailSegmentCustomers**](docs/StorefrontApi.md#searchemailsegmentcustomers) | **GET** /storefront/{storefront_oid}/email/segments/{email_segment_uuid}/search | Search email segment customers
*StorefrontApi* | [**SearchLibraryItems**](docs/StorefrontApi.md#searchlibraryitems) | **POST** /storefront/code_library/search | Retrieve library items
*StorefrontApi* | [**SearchPublishedItems**](docs/StorefrontApi.md#searchpublisheditems) | **POST** /storefront/code_library/search_published | Retrieve library items
*StorefrontApi* | [**SearchReviewItems**](docs/StorefrontApi.md#searchreviewitems) | **POST** /storefront/code_library/search_review | Retrieve library items needing review or rejected
*StorefrontApi* | [**SearchSharedItems**](docs/StorefrontApi.md#searchshareditems) | **POST** /storefront/code_library/search_shared | Retrieve library items
*StorefrontApi* | [**SendEmailTest**](docs/StorefrontApi.md#sendemailtest) | **POST** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid}/test | Send email test
*StorefrontApi* | [**SendPostcardTest**](docs/StorefrontApi.md#sendpostcardtest) | **POST** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid}/test | Send postcard test
*StorefrontApi* | [**SendSmsTest**](docs/StorefrontApi.md#sendsmstest) | **POST** /storefront/{storefront_oid}/email/sms/{commseq_uuid}/{commseq_step_uuid}/test | Send SMS test
*StorefrontApi* | [**SendWebhookTest**](docs/StorefrontApi.md#sendwebhooktest) | **POST** /storefront/{storefront_oid}/email/webhooks/test | Send webhook test
*StorefrontApi* | [**SequenceTest**](docs/StorefrontApi.md#sequencetest) | **POST** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid}/test | Sequence test
*StorefrontApi* | [**StartEmailCampaign**](docs/StorefrontApi.md#startemailcampaign) | **PUT** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid}/start | Start email campaign
*StorefrontApi* | [**SubscribeToEmailList**](docs/StorefrontApi.md#subscribetoemaillist) | **POST** /storefront/{storefront_oid}/email/lists/{email_list_uuid}/subscribe | Subscribe customers to email list
*StorefrontApi* | [**UnfavoriteScreenRecording**](docs/StorefrontApi.md#unfavoritescreenrecording) | **DELETE** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/favorite | Remove favorite flag on screen recording
*StorefrontApi* | [**UpdateEmailCampaign**](docs/StorefrontApi.md#updateemailcampaign) | **PUT** /storefront/{storefront_oid}/email/campaigns/{email_campaign_uuid} | Update email campaign
*StorefrontApi* | [**UpdateEmailCampaignFolder**](docs/StorefrontApi.md#updateemailcampaignfolder) | **PUT** /storefront/{storefront_oid}/email/campaign_folders/{email_campaign_folder_uuid} | Update email campaign folder
*StorefrontApi* | [**UpdateEmailCommseq**](docs/StorefrontApi.md#updateemailcommseq) | **PUT** /storefront/{storefront_oid}/email/commseqs/{commseq_uuid} | Update email commseq
*StorefrontApi* | [**UpdateEmailCustomer**](docs/StorefrontApi.md#updateemailcustomer) | **PUT** /storefront/{storefront_oid}/email/customers/{email_customer_uuid} | Update email customer
*StorefrontApi* | [**UpdateEmailEmail**](docs/StorefrontApi.md#updateemailemail) | **PUT** /storefront/{storefront_oid}/email/emails/{commseq_email_uuid} | Update email email
*StorefrontApi* | [**UpdateEmailFlow**](docs/StorefrontApi.md#updateemailflow) | **PUT** /storefront/{storefront_oid}/email/flows/{email_flow_uuid} | Update email flow
*StorefrontApi* | [**UpdateEmailFlowFolder**](docs/StorefrontApi.md#updateemailflowfolder) | **PUT** /storefront/{storefront_oid}/email/flow_folders/{email_flow_folder_uuid} | Update email flow folder
*StorefrontApi* | [**UpdateEmailGlobalSettings**](docs/StorefrontApi.md#updateemailglobalsettings) | **POST** /storefront/email/global_settings | Update email global settings
*StorefrontApi* | [**UpdateEmailList**](docs/StorefrontApi.md#updateemaillist) | **PUT** /storefront/{storefront_oid}/email/lists/{email_list_uuid} | Update email list
*StorefrontApi* | [**UpdateEmailListSegmentFolder**](docs/StorefrontApi.md#updateemaillistsegmentfolder) | **PUT** /storefront/{storefront_oid}/email/list_segment_folders/{email_list_segment_folder_uuid} | Update email campaign folder
*StorefrontApi* | [**UpdateEmailPlan**](docs/StorefrontApi.md#updateemailplan) | **POST** /storefront/{storefront_oid}/email/plan | Update email plan
*StorefrontApi* | [**UpdateEmailPostcard**](docs/StorefrontApi.md#updateemailpostcard) | **PUT** /storefront/{storefront_oid}/email/postcards/{commseq_postcard_uuid} | Update email postcard
*StorefrontApi* | [**UpdateEmailSegment**](docs/StorefrontApi.md#updateemailsegment) | **PUT** /storefront/{storefront_oid}/email/segments/{email_segment_uuid} | Update email segment
*StorefrontApi* | [**UpdateEmailSendingDomain**](docs/StorefrontApi.md#updateemailsendingdomain) | **PUT** /storefront/email/sending_domains/{domain} | Update email sending domain
*StorefrontApi* | [**UpdateEmailSettings**](docs/StorefrontApi.md#updateemailsettings) | **POST** /storefront/{storefront_oid}/email/settings | Update email settings
*StorefrontApi* | [**UpdateExperiment**](docs/StorefrontApi.md#updateexperiment) | **PUT** /storefront/{storefront_oid}/experiments/{storefront_experiment_oid} | Update experiment
*StorefrontApi* | [**UpdateLibraryItem**](docs/StorefrontApi.md#updatelibraryitem) | **PUT** /storefront/code_library/{library_item_oid} | Update library item. Note that only certain fields may be updated via this method.
*StorefrontApi* | [**UpdateScreenRecordingMerchantNotes**](docs/StorefrontApi.md#updatescreenrecordingmerchantnotes) | **POST** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/merchant_notes | Update merchant notes on a screen recording
*StorefrontApi* | [**UpdateScreenRecordingSegment**](docs/StorefrontApi.md#updatescreenrecordingsegment) | **POST** /storefront/{storefront_oid}/screen_recordings/segments/{screen_recording_segment_oid} | Update screen recording segment
*StorefrontApi* | [**UpdateScreenRecordingSettings**](docs/StorefrontApi.md#updatescreenrecordingsettings) | **POST** /storefront/{storefront_oid}/screen_recordings/settings | Update screen recording settings
*StorefrontApi* | [**UpdateScreenRecordingTags**](docs/StorefrontApi.md#updatescreenrecordingtags) | **POST** /storefront/{storefront_oid}/screen_recordings/{screen_recording_uuid}/tags | Update tags on a screen recording
*StorefrontApi* | [**UpdateTransactionEmail**](docs/StorefrontApi.md#updatetransactionemail) | **PUT** /storefront/{storefront_oid}/transaction_email/list/{email_id} | Updates a transaction email object
*StorefrontApi* | [**UpdateTwilioAccount**](docs/StorefrontApi.md#updatetwilioaccount) | **PUT** /storefront/twilio/accounts/{esp_twilio_uuid} | Update Twilio account
*StorefrontApi* | [**UploadFsFile**](docs/StorefrontApi.md#uploadfsfile) | **POST** /storefront/{id}/fs/upload | This is the last step in uploading a file after 1) calling getUploadFsFileUrl and 2) uploading a file to the provided url, then finally 3) calling this method and providing the key to trigger the server into reading the S3 bucket and retrieving the file.
*StorefrontApi* | [**ValidateRuler**](docs/StorefrontApi.md#validateruler) | **POST** /storefront/ruler/validate | Validate AWS Event Ruler
*TaxApi* | [**DeleteTaxProviderSelfCity**](docs/TaxApi.md#deletetaxproviderselfcity) | **DELETE** /tax/providers/self/city/{city} | Deletes a Self tax provider city
*TaxApi* | [**DeleteTaxProviderSelfCountry**](docs/TaxApi.md#deletetaxproviderselfcountry) | **DELETE** /tax/providers/self/country/{countryCode} | Deletes a Self tax provider country
*TaxApi* | [**DeleteTaxProviderSelfCounty**](docs/TaxApi.md#deletetaxproviderselfcounty) | **DELETE** /tax/providers/self/county/{county} | Deletes a Self tax provider county
*TaxApi* | [**DeleteTaxProviderSelfPostalCode**](docs/TaxApi.md#deletetaxproviderselfpostalcode) | **DELETE** /tax/providers/self/postalCode/{postal_code} | Deletes a Self tax provider postalCode
*TaxApi* | [**DeleteTaxProviderSelfState**](docs/TaxApi.md#deletetaxproviderselfstate) | **DELETE** /tax/providers/self/state/{stateCode} | Deletes a Self tax provider state
*TaxApi* | [**GetTaxProviderAvalara**](docs/TaxApi.md#gettaxprovideravalara) | **GET** /tax/providers/avalara | Retrieve the Avalara tax provider
*TaxApi* | [**GetTaxProviderAvalaraCompanies**](docs/TaxApi.md#gettaxprovideravalaracompanies) | **POST** /tax/providers/avalara/companies | Returns Avalara Tax companies configured by the merchant
*TaxApi* | [**GetTaxProviderAvalaraTest**](docs/TaxApi.md#gettaxprovideravalaratest) | **GET** /tax/providers/avalara/test | Attempts to connect to Avalara and returns back the response
*TaxApi* | [**GetTaxProviderSelf**](docs/TaxApi.md#gettaxproviderself) | **GET** /tax/providers/self | Retrieve the Self tax provider
*TaxApi* | [**GetTaxProviderSelfCountries**](docs/TaxApi.md#gettaxproviderselfcountries) | **GET** /tax/providers/self/countries | Retrieve the Self tax provider countries
*TaxApi* | [**GetTaxProviderSelfRegionsByCountryCode**](docs/TaxApi.md#gettaxproviderselfregionsbycountrycode) | **GET** /tax/providers/self/regions/{countryCode} | Retrieve the Self tax provider regions for a given country code
*TaxApi* | [**GetTaxProviderSovos**](docs/TaxApi.md#gettaxprovidersovos) | **GET** /tax/providers/sovos | Retrieve the Sovos tax provider
*TaxApi* | [**GetTaxProviderSovosTest**](docs/TaxApi.md#gettaxprovidersovostest) | **GET** /tax/providers/sovos/test | Attempts to connect to Sovos and returns back the response
*TaxApi* | [**GetTaxProviderTaxJar**](docs/TaxApi.md#gettaxprovidertaxjar) | **GET** /tax/providers/taxjar | Retrieve the TaxJar tax provider
*TaxApi* | [**GetTaxProviderTaxJarTest**](docs/TaxApi.md#gettaxprovidertaxjartest) | **GET** /tax/providers/taxjar/test | Attempts to connect to TaxJar and returns back the response
*TaxApi* | [**GetTaxProviderUltraCart**](docs/TaxApi.md#gettaxproviderultracart) | **GET** /tax/providers/ultracart | Retrieve the UltraCart tax provider
*TaxApi* | [**GetTaxProviders**](docs/TaxApi.md#gettaxproviders) | **GET** /tax/providers | Retrieve tax methods
*TaxApi* | [**SetActiveTaxProvider**](docs/TaxApi.md#setactivetaxprovider) | **POST** /tax/providers/setActive/{providerName} | Toggle a tax provider to active
*TaxApi* | [**UpdateTaxProviderAvalara**](docs/TaxApi.md#updatetaxprovideravalara) | **POST** /tax/providers/avalara | Update the Avalara tax provider
*TaxApi* | [**UpdateTaxProviderSelf**](docs/TaxApi.md#updatetaxproviderself) | **POST** /tax/providers/self | Update the Self tax provider
*TaxApi* | [**UpdateTaxProviderSelfCity**](docs/TaxApi.md#updatetaxproviderselfcity) | **POST** /tax/providers/self/city/{city} | Updates a Self tax provider city
*TaxApi* | [**UpdateTaxProviderSelfCountry**](docs/TaxApi.md#updatetaxproviderselfcountry) | **POST** /tax/providers/self/country/{countryCode} | Updates a Self tax provider country
*TaxApi* | [**UpdateTaxProviderSelfCounty**](docs/TaxApi.md#updatetaxproviderselfcounty) | **POST** /tax/providers/self/county/{county} | Updates a Self tax provider county
*TaxApi* | [**UpdateTaxProviderSelfPostalCode**](docs/TaxApi.md#updatetaxproviderselfpostalcode) | **POST** /tax/providers/self/postalCode/{postal_code} | Updates a Self tax provider postalCode
*TaxApi* | [**UpdateTaxProviderSelfState**](docs/TaxApi.md#updatetaxproviderselfstate) | **POST** /tax/providers/self/state/{stateCode} | Updates a Self tax provider state
*TaxApi* | [**UpdateTaxProviderSovos**](docs/TaxApi.md#updatetaxprovidersovos) | **POST** /tax/providers/sovos | Update the Sovos tax provider
*TaxApi* | [**UpdateTaxProviderTaxJar**](docs/TaxApi.md#updatetaxprovidertaxjar) | **POST** /tax/providers/taxjar | Update the TaxJar tax provider
*TaxApi* | [**UpdateTaxProviderUltraCart**](docs/TaxApi.md#updatetaxproviderultracart) | **POST** /tax/providers/ultracart | Update the UltraCart tax provider
*UserApi* | [**DeleteGroup**](docs/UserApi.md#deletegroup) | **DELETE** /user/groups/{group_oid} | Delete a group
*UserApi* | [**DeleteUser**](docs/UserApi.md#deleteuser) | **DELETE** /user/users/{user_id} | Delete a user
*UserApi* | [**GetGroup**](docs/UserApi.md#getgroup) | **GET** /user/groups/{group_oid} | Retrieve a group
*UserApi* | [**GetGroups**](docs/UserApi.md#getgroups) | **GET** /user/groups | Get groups
*UserApi* | [**GetUser**](docs/UserApi.md#getuser) | **GET** /user/users/{user_id} | Retrieve a user
*UserApi* | [**GetUserLogins**](docs/UserApi.md#getuserlogins) | **GET** /user/users/{user_id}/logins | Retrieve a user's login history
*UserApi* | [**GetUsers**](docs/UserApi.md#getusers) | **GET** /user/users | Get users
*UserApi* | [**InsertGroup**](docs/UserApi.md#insertgroup) | **POST** /user/groups | Insert a group
*UserApi* | [**InsertUser**](docs/UserApi.md#insertuser) | **POST** /user/users | Insert a user
*UserApi* | [**UpdateGroup**](docs/UserApi.md#updategroup) | **PUT** /user/groups/{group_oid} | Update a group
*UserApi* | [**UpdateUser**](docs/UserApi.md#updateuser) | **PUT** /user/users/{user_id} | Update a user
*WebhookApi* | [**DeleteWebhook**](docs/WebhookApi.md#deletewebhook) | **DELETE** /webhook/webhooks/{webhookOid} | Delete a webhook
*WebhookApi* | [**DeleteWebhookByUrl**](docs/WebhookApi.md#deletewebhookbyurl) | **DELETE** /webhook/webhooks | Delete a webhook by URL
*WebhookApi* | [**GetWebhookLog**](docs/WebhookApi.md#getwebhooklog) | **GET** /webhook/webhooks/{webhookOid}/logs/{requestId} | Retrieve an individual log
*WebhookApi* | [**GetWebhookLogSummaries**](docs/WebhookApi.md#getwebhooklogsummaries) | **GET** /webhook/webhooks/{webhookOid}/logs | Retrieve the log summaries
*WebhookApi* | [**GetWebhooks**](docs/WebhookApi.md#getwebhooks) | **GET** /webhook/webhooks | Retrieve webhooks
*WebhookApi* | [**InsertWebhook**](docs/WebhookApi.md#insertwebhook) | **POST** /webhook/webhooks | Add a webhook
*WebhookApi* | [**ResendEvent**](docs/WebhookApi.md#resendevent) | **POST** /webhook/webhooks/{webhookOid}/reflow/{eventName} | Resend events to the webhook endpoint.
*WebhookApi* | [**UpdateWebhook**](docs/WebhookApi.md#updatewebhook) | **PUT** /webhook/webhooks/{webhookOid} | Update a webhook


## Documentation for Models

 - [Model.AccountsReceivableRetryConfig](docs/AccountsReceivableRetryConfig.md)
 - [Model.AccountsReceivableRetryConfigResponse](docs/AccountsReceivableRetryConfigResponse.md)
 - [Model.AccountsReceivableRetryDayActivity](docs/AccountsReceivableRetryDayActivity.md)
 - [Model.AccountsReceivableRetryStatAccount](docs/AccountsReceivableRetryStatAccount.md)
 - [Model.AccountsReceivableRetryStatMetrics](docs/AccountsReceivableRetryStatMetrics.md)
 - [Model.AccountsReceivableRetryStatRevenue](docs/AccountsReceivableRetryStatRevenue.md)
 - [Model.AccountsReceivableRetryStatsResponse](docs/AccountsReceivableRetryStatsResponse.md)
 - [Model.AccountsReceivableRetryTransactionReject](docs/AccountsReceivableRetryTransactionReject.md)
 - [Model.Activity](docs/Activity.md)
 - [Model.AddLibraryItemRequest](docs/AddLibraryItemRequest.md)
 - [Model.AdjustInternalCertificateRequest](docs/AdjustInternalCertificateRequest.md)
 - [Model.AdjustInternalCertificateResponse](docs/AdjustInternalCertificateResponse.md)
 - [Model.AffiliateClick](docs/AffiliateClick.md)
 - [Model.AffiliateClickQuery](docs/AffiliateClickQuery.md)
 - [Model.AffiliateClicksResponse](docs/AffiliateClicksResponse.md)
 - [Model.AffiliateLedger](docs/AffiliateLedger.md)
 - [Model.AffiliateLedgerQuery](docs/AffiliateLedgerQuery.md)
 - [Model.AffiliateLedgersResponse](docs/AffiliateLedgersResponse.md)
 - [Model.AffiliateLink](docs/AffiliateLink.md)
 - [Model.ApiUserApplicationProfile](docs/ApiUserApplicationProfile.md)
 - [Model.ApplyLibraryItemRequest](docs/ApplyLibraryItemRequest.md)
 - [Model.ApplyLibraryItemResponse](docs/ApplyLibraryItemResponse.md)
 - [Model.AutoOrder](docs/AutoOrder.md)
 - [Model.AutoOrderItem](docs/AutoOrderItem.md)
 - [Model.AutoOrderItemFutureSchedule](docs/AutoOrderItemFutureSchedule.md)
 - [Model.AutoOrderItemOption](docs/AutoOrderItemOption.md)
 - [Model.AutoOrderItemSimpleSchedule](docs/AutoOrderItemSimpleSchedule.md)
 - [Model.AutoOrderLog](docs/AutoOrderLog.md)
 - [Model.AutoOrderManagement](docs/AutoOrderManagement.md)
 - [Model.AutoOrderQuery](docs/AutoOrderQuery.md)
 - [Model.AutoOrderQueryBatch](docs/AutoOrderQueryBatch.md)
 - [Model.AutoOrderResponse](docs/AutoOrderResponse.md)
 - [Model.AutoOrdersRequest](docs/AutoOrdersRequest.md)
 - [Model.AutoOrdersResponse](docs/AutoOrdersResponse.md)
 - [Model.AvalaraConfig](docs/AvalaraConfig.md)
 - [Model.BaseResponse](docs/BaseResponse.md)
 - [Model.Browser](docs/Browser.md)
 - [Model.BrowserDevice](docs/BrowserDevice.md)
 - [Model.BrowserOS](docs/BrowserOS.md)
 - [Model.BrowserUserAgent](docs/BrowserUserAgent.md)
 - [Model.Cart](docs/Cart.md)
 - [Model.CartAffiliate](docs/CartAffiliate.md)
 - [Model.CartAffirmCheckoutResponse](docs/CartAffirmCheckoutResponse.md)
 - [Model.CartBilling](docs/CartBilling.md)
 - [Model.CartBuysafe](docs/CartBuysafe.md)
 - [Model.CartCheckout](docs/CartCheckout.md)
 - [Model.CartCoupon](docs/CartCoupon.md)
 - [Model.CartCurrencyConversion](docs/CartCurrencyConversion.md)
 - [Model.CartCustomerProfile](docs/CartCustomerProfile.md)
 - [Model.CartCustomerProfileAddress](docs/CartCustomerProfileAddress.md)
 - [Model.CartCustomerProfileCreditCard](docs/CartCustomerProfileCreditCard.md)
 - [Model.CartFinalizeOrderRequest](docs/CartFinalizeOrderRequest.md)
 - [Model.CartFinalizeOrderRequestOptions](docs/CartFinalizeOrderRequestOptions.md)
 - [Model.CartFinalizeOrderResponse](docs/CartFinalizeOrderResponse.md)
 - [Model.CartGift](docs/CartGift.md)
 - [Model.CartGiftCertificate](docs/CartGiftCertificate.md)
 - [Model.CartItem](docs/CartItem.md)
 - [Model.CartItemAttribute](docs/CartItemAttribute.md)
 - [Model.CartItemMultimedia](docs/CartItemMultimedia.md)
 - [Model.CartItemMultimediaThumbnail](docs/CartItemMultimediaThumbnail.md)
 - [Model.CartItemOption](docs/CartItemOption.md)
 - [Model.CartItemOptionValue](docs/CartItemOptionValue.md)
 - [Model.CartItemPhysical](docs/CartItemPhysical.md)
 - [Model.CartItemProperty](docs/CartItemProperty.md)
 - [Model.CartItemVariationSelection](docs/CartItemVariationSelection.md)
 - [Model.CartKitComponentOption](docs/CartKitComponentOption.md)
 - [Model.CartMarketing](docs/CartMarketing.md)
 - [Model.CartPayment](docs/CartPayment.md)
 - [Model.CartPaymentAffirm](docs/CartPaymentAffirm.md)
 - [Model.CartPaymentAmazon](docs/CartPaymentAmazon.md)
 - [Model.CartPaymentCheck](docs/CartPaymentCheck.md)
 - [Model.CartPaymentCreditCard](docs/CartPaymentCreditCard.md)
 - [Model.CartPaymentPurchaseOrder](docs/CartPaymentPurchaseOrder.md)
 - [Model.CartProfileLoginRequest](docs/CartProfileLoginRequest.md)
 - [Model.CartProfileLoginResponse](docs/CartProfileLoginResponse.md)
 - [Model.CartProfileRegisterRequest](docs/CartProfileRegisterRequest.md)
 - [Model.CartProfileRegisterResponse](docs/CartProfileRegisterResponse.md)
 - [Model.CartProperty](docs/CartProperty.md)
 - [Model.CartResponse](docs/CartResponse.md)
 - [Model.CartSettings](docs/CartSettings.md)
 - [Model.CartSettingsBilling](docs/CartSettingsBilling.md)
 - [Model.CartSettingsGift](docs/CartSettingsGift.md)
 - [Model.CartSettingsGiftWrap](docs/CartSettingsGiftWrap.md)
 - [Model.CartSettingsPayment](docs/CartSettingsPayment.md)
 - [Model.CartSettingsPaymentAmazon](docs/CartSettingsPaymentAmazon.md)
 - [Model.CartSettingsPaymentCreditCard](docs/CartSettingsPaymentCreditCard.md)
 - [Model.CartSettingsPaymentPayPal](docs/CartSettingsPaymentPayPal.md)
 - [Model.CartSettingsProvince](docs/CartSettingsProvince.md)
 - [Model.CartSettingsShipping](docs/CartSettingsShipping.md)
 - [Model.CartSettingsShippingCalendar](docs/CartSettingsShippingCalendar.md)
 - [Model.CartSettingsShippingEstimate](docs/CartSettingsShippingEstimate.md)
 - [Model.CartSettingsTaxes](docs/CartSettingsTaxes.md)
 - [Model.CartSettingsTerms](docs/CartSettingsTerms.md)
 - [Model.CartShipping](docs/CartShipping.md)
 - [Model.CartSummary](docs/CartSummary.md)
 - [Model.CartTaxes](docs/CartTaxes.md)
 - [Model.CartUpsellAfter](docs/CartUpsellAfter.md)
 - [Model.CartValidationRequest](docs/CartValidationRequest.md)
 - [Model.CartValidationResponse](docs/CartValidationResponse.md)
 - [Model.ChannelPartner](docs/ChannelPartner.md)
 - [Model.ChannelPartnerCancelResponse](docs/ChannelPartnerCancelResponse.md)
 - [Model.ChannelPartnerEstimateShippingResponse](docs/ChannelPartnerEstimateShippingResponse.md)
 - [Model.ChannelPartnerEstimateTaxResponse](docs/ChannelPartnerEstimateTaxResponse.md)
 - [Model.ChannelPartnerImportResponse](docs/ChannelPartnerImportResponse.md)
 - [Model.ChannelPartnerOrder](docs/ChannelPartnerOrder.md)
 - [Model.ChannelPartnerOrderItem](docs/ChannelPartnerOrderItem.md)
 - [Model.ChannelPartnerOrderItemOption](docs/ChannelPartnerOrderItemOption.md)
 - [Model.ChannelPartnerOrderTransaction](docs/ChannelPartnerOrderTransaction.md)
 - [Model.ChannelPartnerOrderTransactionDetail](docs/ChannelPartnerOrderTransactionDetail.md)
 - [Model.ChannelPartnerShipToPreference](docs/ChannelPartnerShipToPreference.md)
 - [Model.ChannelPartnerShipToPreferenceResponse](docs/ChannelPartnerShipToPreferenceResponse.md)
 - [Model.ChannelPartnerShipToPreferencesResponse](docs/ChannelPartnerShipToPreferencesResponse.md)
 - [Model.ChannelPartnerShippingEstimate](docs/ChannelPartnerShippingEstimate.md)
 - [Model.ChannelPartnersResponse](docs/ChannelPartnersResponse.md)
 - [Model.ChargebackDispute](docs/ChargebackDispute.md)
 - [Model.ChargebackDisputeResponse](docs/ChargebackDisputeResponse.md)
 - [Model.ChargebackDisputesResponse](docs/ChargebackDisputesResponse.md)
 - [Model.CheckoutAllowedCountriesResponse](docs/CheckoutAllowedCountriesResponse.md)
 - [Model.CheckoutHandoffRequest](docs/CheckoutHandoffRequest.md)
 - [Model.CheckoutHandoffResponse](docs/CheckoutHandoffResponse.md)
 - [Model.CheckoutSetupBrowserKeyRequest](docs/CheckoutSetupBrowserKeyRequest.md)
 - [Model.CheckoutSetupBrowserKeyResponse](docs/CheckoutSetupBrowserKeyResponse.md)
 - [Model.CheckoutStateProvinceResponse](docs/CheckoutStateProvinceResponse.md)
 - [Model.CityStateZip](docs/CityStateZip.md)
 - [Model.Conversation](docs/Conversation.md)
 - [Model.ConversationAgentAuth](docs/ConversationAgentAuth.md)
 - [Model.ConversationAgentAuthResponse](docs/ConversationAgentAuthResponse.md)
 - [Model.ConversationAgentProfile](docs/ConversationAgentProfile.md)
 - [Model.ConversationAgentProfileResponse](docs/ConversationAgentProfileResponse.md)
 - [Model.ConversationAutocompleteRequest](docs/ConversationAutocompleteRequest.md)
 - [Model.ConversationAutocompleteResponse](docs/ConversationAutocompleteResponse.md)
 - [Model.ConversationAutocompleteValue](docs/ConversationAutocompleteValue.md)
 - [Model.ConversationCannedMessage](docs/ConversationCannedMessage.md)
 - [Model.ConversationCannedMessageResponse](docs/ConversationCannedMessageResponse.md)
 - [Model.ConversationCannedMessagesResponse](docs/ConversationCannedMessagesResponse.md)
 - [Model.ConversationCannedMessagesSearch](docs/ConversationCannedMessagesSearch.md)
 - [Model.ConversationDepartment](docs/ConversationDepartment.md)
 - [Model.ConversationDepartmentMember](docs/ConversationDepartmentMember.md)
 - [Model.ConversationDepartmentMembersResponse](docs/ConversationDepartmentMembersResponse.md)
 - [Model.ConversationDepartmentResponse](docs/ConversationDepartmentResponse.md)
 - [Model.ConversationDepartmentsResponse](docs/ConversationDepartmentsResponse.md)
 - [Model.ConversationEngagement](docs/ConversationEngagement.md)
 - [Model.ConversationEngagementEquation](docs/ConversationEngagementEquation.md)
 - [Model.ConversationEngagementEquationFunction](docs/ConversationEngagementEquationFunction.md)
 - [Model.ConversationEngagementEquationGroup](docs/ConversationEngagementEquationGroup.md)
 - [Model.ConversationEngagementResponse](docs/ConversationEngagementResponse.md)
 - [Model.ConversationEngagementsResponse](docs/ConversationEngagementsResponse.md)
 - [Model.ConversationEventAddCoupon](docs/ConversationEventAddCoupon.md)
 - [Model.ConversationEventAddItem](docs/ConversationEventAddItem.md)
 - [Model.ConversationEventQueuePosition](docs/ConversationEventQueuePosition.md)
 - [Model.ConversationEventRRWeb](docs/ConversationEventRRWeb.md)
 - [Model.ConversationEventReadMessage](docs/ConversationEventReadMessage.md)
 - [Model.ConversationEventTyping](docs/ConversationEventTyping.md)
 - [Model.ConversationEventWebchatContext](docs/ConversationEventWebchatContext.md)
 - [Model.ConversationJoinRequest](docs/ConversationJoinRequest.md)
 - [Model.ConversationLocationCountry](docs/ConversationLocationCountry.md)
 - [Model.ConversationLocationStateProvince](docs/ConversationLocationStateProvince.md)
 - [Model.ConversationLocationsResponse](docs/ConversationLocationsResponse.md)
 - [Model.ConversationMessage](docs/ConversationMessage.md)
 - [Model.ConversationMessageTranslation](docs/ConversationMessageTranslation.md)
 - [Model.ConversationMessageTransportStatus](docs/ConversationMessageTransportStatus.md)
 - [Model.ConversationMessagesResponse](docs/ConversationMessagesResponse.md)
 - [Model.ConversationMultimediaUploadUrl](docs/ConversationMultimediaUploadUrl.md)
 - [Model.ConversationMultimediaUploadUrlResponse](docs/ConversationMultimediaUploadUrlResponse.md)
 - [Model.ConversationParticipant](docs/ConversationParticipant.md)
 - [Model.ConversationPermissions](docs/ConversationPermissions.md)
 - [Model.ConversationPermissionsResponse](docs/ConversationPermissionsResponse.md)
 - [Model.ConversationResponse](docs/ConversationResponse.md)
 - [Model.ConversationSearchRequest](docs/ConversationSearchRequest.md)
 - [Model.ConversationSearchResponse](docs/ConversationSearchResponse.md)
 - [Model.ConversationSentiment](docs/ConversationSentiment.md)
 - [Model.ConversationStartRequest](docs/ConversationStartRequest.md)
 - [Model.ConversationStartResponse](docs/ConversationStartResponse.md)
 - [Model.ConversationSummary](docs/ConversationSummary.md)
 - [Model.ConversationTwilioAccount](docs/ConversationTwilioAccount.md)
 - [Model.ConversationWebchatContext](docs/ConversationWebchatContext.md)
 - [Model.ConversationWebchatQueueStatus](docs/ConversationWebchatQueueStatus.md)
 - [Model.ConversationWebchatQueueStatusAgent](docs/ConversationWebchatQueueStatusAgent.md)
 - [Model.ConversationWebchatQueueStatusQueueEntry](docs/ConversationWebchatQueueStatusQueueEntry.md)
 - [Model.ConversationWebchatQueueStatusUpdateRequest](docs/ConversationWebchatQueueStatusUpdateRequest.md)
 - [Model.ConversationWebchatQueueStatusesResponse](docs/ConversationWebchatQueueStatusesResponse.md)
 - [Model.ConversationWebsocketMessage](docs/ConversationWebsocketMessage.md)
 - [Model.ConversationsResponse](docs/ConversationsResponse.md)
 - [Model.CountriesResponse](docs/CountriesResponse.md)
 - [Model.Country](docs/Country.md)
 - [Model.Coupon](docs/Coupon.md)
 - [Model.CouponAmountOffItems](docs/CouponAmountOffItems.md)
 - [Model.CouponAmountOffShipping](docs/CouponAmountOffShipping.md)
 - [Model.CouponAmountOffShippingWithItemsPurchase](docs/CouponAmountOffShippingWithItemsPurchase.md)
 - [Model.CouponAmountOffSubtotal](docs/CouponAmountOffSubtotal.md)
 - [Model.CouponAmountOffSubtotalAndShipping](docs/CouponAmountOffSubtotalAndShipping.md)
 - [Model.CouponAmountOffSubtotalFreeShippingWithPurchase](docs/CouponAmountOffSubtotalFreeShippingWithPurchase.md)
 - [Model.CouponAmountOffSubtotalWithBlockPurchase](docs/CouponAmountOffSubtotalWithBlockPurchase.md)
 - [Model.CouponAmountOffSubtotalWithItemsPurchase](docs/CouponAmountOffSubtotalWithItemsPurchase.md)
 - [Model.CouponAmountOffSubtotalWithPurchase](docs/CouponAmountOffSubtotalWithPurchase.md)
 - [Model.CouponAmountShippingWithSubtotal](docs/CouponAmountShippingWithSubtotal.md)
 - [Model.CouponAutoApplyCondition](docs/CouponAutoApplyCondition.md)
 - [Model.CouponAutoApplyConditions](docs/CouponAutoApplyConditions.md)
 - [Model.CouponAutomaticallyApplyCouponCodes](docs/CouponAutomaticallyApplyCouponCodes.md)
 - [Model.CouponBuyOneGetOneLimit](docs/CouponBuyOneGetOneLimit.md)
 - [Model.CouponCodesRequest](docs/CouponCodesRequest.md)
 - [Model.CouponCodesResponse](docs/CouponCodesResponse.md)
 - [Model.CouponDeletesRequest](docs/CouponDeletesRequest.md)
 - [Model.CouponDiscountItemWithItemPurchase](docs/CouponDiscountItemWithItemPurchase.md)
 - [Model.CouponDiscountItems](docs/CouponDiscountItems.md)
 - [Model.CouponEditorValues](docs/CouponEditorValues.md)
 - [Model.CouponExistsResponse](docs/CouponExistsResponse.md)
 - [Model.CouponFreeItemAndShippingWithSubtotal](docs/CouponFreeItemAndShippingWithSubtotal.md)
 - [Model.CouponFreeItemWithItemPurchase](docs/CouponFreeItemWithItemPurchase.md)
 - [Model.CouponFreeItemWithSubtotal](docs/CouponFreeItemWithSubtotal.md)
 - [Model.CouponFreeItemsWithItemPurchase](docs/CouponFreeItemsWithItemPurchase.md)
 - [Model.CouponFreeItemsWithMixMatchPurchase](docs/CouponFreeItemsWithMixMatchPurchase.md)
 - [Model.CouponFreeShipping](docs/CouponFreeShipping.md)
 - [Model.CouponFreeShippingSpecificItems](docs/CouponFreeShippingSpecificItems.md)
 - [Model.CouponFreeShippingWithItemsPurchase](docs/CouponFreeShippingWithItemsPurchase.md)
 - [Model.CouponFreeShippingWithSubtotal](docs/CouponFreeShippingWithSubtotal.md)
 - [Model.CouponItemSearchResult](docs/CouponItemSearchResult.md)
 - [Model.CouponItemSearchResultsResponse](docs/CouponItemSearchResultsResponse.md)
 - [Model.CouponMoreLoyaltyCashback](docs/CouponMoreLoyaltyCashback.md)
 - [Model.CouponMoreLoyaltyPoints](docs/CouponMoreLoyaltyPoints.md)
 - [Model.CouponMultipleAmountsOffItems](docs/CouponMultipleAmountsOffItems.md)
 - [Model.CouponNoDiscount](docs/CouponNoDiscount.md)
 - [Model.CouponPercentMoreLoyaltyCashback](docs/CouponPercentMoreLoyaltyCashback.md)
 - [Model.CouponPercentMoreLoyaltyPoints](docs/CouponPercentMoreLoyaltyPoints.md)
 - [Model.CouponPercentOffItemWithItemsQuantityPurchase](docs/CouponPercentOffItemWithItemsQuantityPurchase.md)
 - [Model.CouponPercentOffItems](docs/CouponPercentOffItems.md)
 - [Model.CouponPercentOffItemsAndFreeShipping](docs/CouponPercentOffItemsAndFreeShipping.md)
 - [Model.CouponPercentOffItemsWithItemsPurchase](docs/CouponPercentOffItemsWithItemsPurchase.md)
 - [Model.CouponPercentOffMsrpItems](docs/CouponPercentOffMsrpItems.md)
 - [Model.CouponPercentOffRetailPriceItems](docs/CouponPercentOffRetailPriceItems.md)
 - [Model.CouponPercentOffShipping](docs/CouponPercentOffShipping.md)
 - [Model.CouponPercentOffSubtotal](docs/CouponPercentOffSubtotal.md)
 - [Model.CouponPercentOffSubtotalAndFreeShipping](docs/CouponPercentOffSubtotalAndFreeShipping.md)
 - [Model.CouponPercentOffSubtotalLimit](docs/CouponPercentOffSubtotalLimit.md)
 - [Model.CouponPercentOffSubtotalWithItemsPurchase](docs/CouponPercentOffSubtotalWithItemsPurchase.md)
 - [Model.CouponPercentOffSubtotalWithSubtotal](docs/CouponPercentOffSubtotalWithSubtotal.md)
 - [Model.CouponQuery](docs/CouponQuery.md)
 - [Model.CouponResponse](docs/CouponResponse.md)
 - [Model.CouponRestriction](docs/CouponRestriction.md)
 - [Model.CouponTierAmount](docs/CouponTierAmount.md)
 - [Model.CouponTierItemDiscount](docs/CouponTierItemDiscount.md)
 - [Model.CouponTierPercent](docs/CouponTierPercent.md)
 - [Model.CouponTierQuantityAmount](docs/CouponTierQuantityAmount.md)
 - [Model.CouponTierQuantityPercent](docs/CouponTierQuantityPercent.md)
 - [Model.CouponTieredAmountOffItems](docs/CouponTieredAmountOffItems.md)
 - [Model.CouponTieredAmountOffSubtotal](docs/CouponTieredAmountOffSubtotal.md)
 - [Model.CouponTieredPercentOffItems](docs/CouponTieredPercentOffItems.md)
 - [Model.CouponTieredPercentOffShipping](docs/CouponTieredPercentOffShipping.md)
 - [Model.CouponTieredPercentOffSubtotal](docs/CouponTieredPercentOffSubtotal.md)
 - [Model.CouponTieredPercentOffSubtotalBasedOnMSRP](docs/CouponTieredPercentOffSubtotalBasedOnMSRP.md)
 - [Model.CouponType](docs/CouponType.md)
 - [Model.CouponsRequest](docs/CouponsRequest.md)
 - [Model.CouponsResponse](docs/CouponsResponse.md)
 - [Model.Currency](docs/Currency.md)
 - [Model.Customer](docs/Customer.md)
 - [Model.CustomerActivity](docs/CustomerActivity.md)
 - [Model.CustomerAffiliate](docs/CustomerAffiliate.md)
 - [Model.CustomerAttachment](docs/CustomerAttachment.md)
 - [Model.CustomerBilling](docs/CustomerBilling.md)
 - [Model.CustomerCard](docs/CustomerCard.md)
 - [Model.CustomerEDI](docs/CustomerEDI.md)
 - [Model.CustomerEditorValues](docs/CustomerEditorValues.md)
 - [Model.CustomerEmail](docs/CustomerEmail.md)
 - [Model.CustomerEmailListChanges](docs/CustomerEmailListChanges.md)
 - [Model.CustomerLoyalty](docs/CustomerLoyalty.md)
 - [Model.CustomerLoyaltyLedger](docs/CustomerLoyaltyLedger.md)
 - [Model.CustomerLoyaltyRedemption](docs/CustomerLoyaltyRedemption.md)
 - [Model.CustomerMagicLinkResponse](docs/CustomerMagicLinkResponse.md)
 - [Model.CustomerMergeRequest](docs/CustomerMergeRequest.md)
 - [Model.CustomerOrdersSummary](docs/CustomerOrdersSummary.md)
 - [Model.CustomerPricingTier](docs/CustomerPricingTier.md)
 - [Model.CustomerPrivacy](docs/CustomerPrivacy.md)
 - [Model.CustomerQuery](docs/CustomerQuery.md)
 - [Model.CustomerQuotesSummary](docs/CustomerQuotesSummary.md)
 - [Model.CustomerResponse](docs/CustomerResponse.md)
 - [Model.CustomerReviewer](docs/CustomerReviewer.md)
 - [Model.CustomerShipping](docs/CustomerShipping.md)
 - [Model.CustomerSoftwareEntitlement](docs/CustomerSoftwareEntitlement.md)
 - [Model.CustomerStoreCredit](docs/CustomerStoreCredit.md)
 - [Model.CustomerStoreCreditAddRequest](docs/CustomerStoreCreditAddRequest.md)
 - [Model.CustomerStoreCreditLedgerEntry](docs/CustomerStoreCreditLedgerEntry.md)
 - [Model.CustomerStoreCreditResponse](docs/CustomerStoreCreditResponse.md)
 - [Model.CustomerTag](docs/CustomerTag.md)
 - [Model.CustomerTaxCodes](docs/CustomerTaxCodes.md)
 - [Model.CustomersResponse](docs/CustomersResponse.md)
 - [Model.DataTablesServerSideResponse](docs/DataTablesServerSideResponse.md)
 - [Model.Distance](docs/Distance.md)
 - [Model.DistributionCenter](docs/DistributionCenter.md)
 - [Model.DistributionCentersResponse](docs/DistributionCentersResponse.md)
 - [Model.EmailBaseTemplateListResponse](docs/EmailBaseTemplateListResponse.md)
 - [Model.EmailCampaign](docs/EmailCampaign.md)
 - [Model.EmailCampaignFolder](docs/EmailCampaignFolder.md)
 - [Model.EmailCampaignFolderResponse](docs/EmailCampaignFolderResponse.md)
 - [Model.EmailCampaignFoldersResponse](docs/EmailCampaignFoldersResponse.md)
 - [Model.EmailCampaignResponse](docs/EmailCampaignResponse.md)
 - [Model.EmailCampaignsResponse](docs/EmailCampaignsResponse.md)
 - [Model.EmailClick](docs/EmailClick.md)
 - [Model.EmailClicksResponse](docs/EmailClicksResponse.md)
 - [Model.EmailCommseq](docs/EmailCommseq.md)
 - [Model.EmailCommseqEmail](docs/EmailCommseqEmail.md)
 - [Model.EmailCommseqEmailResponse](docs/EmailCommseqEmailResponse.md)
 - [Model.EmailCommseqEmailSendTestRequest](docs/EmailCommseqEmailSendTestRequest.md)
 - [Model.EmailCommseqEmailSendTestResponse](docs/EmailCommseqEmailSendTestResponse.md)
 - [Model.EmailCommseqEmailsRequest](docs/EmailCommseqEmailsRequest.md)
 - [Model.EmailCommseqEmailsResponse](docs/EmailCommseqEmailsResponse.md)
 - [Model.EmailCommseqPostcard](docs/EmailCommseqPostcard.md)
 - [Model.EmailCommseqPostcardResponse](docs/EmailCommseqPostcardResponse.md)
 - [Model.EmailCommseqPostcardSendTestRequest](docs/EmailCommseqPostcardSendTestRequest.md)
 - [Model.EmailCommseqPostcardSendTestResponse](docs/EmailCommseqPostcardSendTestResponse.md)
 - [Model.EmailCommseqPostcardsRequest](docs/EmailCommseqPostcardsRequest.md)
 - [Model.EmailCommseqPostcardsResponse](docs/EmailCommseqPostcardsResponse.md)
 - [Model.EmailCommseqResponse](docs/EmailCommseqResponse.md)
 - [Model.EmailCommseqSequenceTestRequest](docs/EmailCommseqSequenceTestRequest.md)
 - [Model.EmailCommseqSequenceTestResponse](docs/EmailCommseqSequenceTestResponse.md)
 - [Model.EmailCommseqSmsSendTestRequest](docs/EmailCommseqSmsSendTestRequest.md)
 - [Model.EmailCommseqSmsSendTestResponse](docs/EmailCommseqSmsSendTestResponse.md)
 - [Model.EmailCommseqStat](docs/EmailCommseqStat.md)
 - [Model.EmailCommseqStatResponse](docs/EmailCommseqStatResponse.md)
 - [Model.EmailCommseqStep](docs/EmailCommseqStep.md)
 - [Model.EmailCommseqStepLog](docs/EmailCommseqStepLog.md)
 - [Model.EmailCommseqStepLogsResponse](docs/EmailCommseqStepLogsResponse.md)
 - [Model.EmailCommseqWebhookSendTestRequest](docs/EmailCommseqWebhookSendTestRequest.md)
 - [Model.EmailCommseqWebhookSendTestResponse](docs/EmailCommseqWebhookSendTestResponse.md)
 - [Model.EmailCommseqsResponse](docs/EmailCommseqsResponse.md)
 - [Model.EmailCustomer](docs/EmailCustomer.md)
 - [Model.EmailCustomerEditorUrlResponse](docs/EmailCustomerEditorUrlResponse.md)
 - [Model.EmailCustomersResponse](docs/EmailCustomersResponse.md)
 - [Model.EmailDashboardActivity](docs/EmailDashboardActivity.md)
 - [Model.EmailDashboardActivityResponse](docs/EmailDashboardActivityResponse.md)
 - [Model.EmailDashboardStatsResponse](docs/EmailDashboardStatsResponse.md)
 - [Model.EmailDomain](docs/EmailDomain.md)
 - [Model.EmailEditorTokenResponse](docs/EmailEditorTokenResponse.md)
 - [Model.EmailFlow](docs/EmailFlow.md)
 - [Model.EmailFlowBackPopulateRequest](docs/EmailFlowBackPopulateRequest.md)
 - [Model.EmailFlowBackPopulateResponse](docs/EmailFlowBackPopulateResponse.md)
 - [Model.EmailFlowFolder](docs/EmailFlowFolder.md)
 - [Model.EmailFlowFolderResponse](docs/EmailFlowFolderResponse.md)
 - [Model.EmailFlowFoldersResponse](docs/EmailFlowFoldersResponse.md)
 - [Model.EmailFlowResponse](docs/EmailFlowResponse.md)
 - [Model.EmailFlowsResponse](docs/EmailFlowsResponse.md)
 - [Model.EmailGlobalSettings](docs/EmailGlobalSettings.md)
 - [Model.EmailGlobalSettingsResponse](docs/EmailGlobalSettingsResponse.md)
 - [Model.EmailGlobalUnsubscribeRequest](docs/EmailGlobalUnsubscribeRequest.md)
 - [Model.EmailGlobalUnsubscribeResponse](docs/EmailGlobalUnsubscribeResponse.md)
 - [Model.EmailHistogramPropertyNamesResponse](docs/EmailHistogramPropertyNamesResponse.md)
 - [Model.EmailHistogramPropertyValuesResponse](docs/EmailHistogramPropertyValuesResponse.md)
 - [Model.EmailList](docs/EmailList.md)
 - [Model.EmailListArchiveResponse](docs/EmailListArchiveResponse.md)
 - [Model.EmailListCustomer](docs/EmailListCustomer.md)
 - [Model.EmailListCustomersResponse](docs/EmailListCustomersResponse.md)
 - [Model.EmailListResponse](docs/EmailListResponse.md)
 - [Model.EmailListSegmentFolder](docs/EmailListSegmentFolder.md)
 - [Model.EmailListSegmentFolderResponse](docs/EmailListSegmentFolderResponse.md)
 - [Model.EmailListSegmentFoldersResponse](docs/EmailListSegmentFoldersResponse.md)
 - [Model.EmailListSegmentMembership](docs/EmailListSegmentMembership.md)
 - [Model.EmailListSegmentUsedBy](docs/EmailListSegmentUsedBy.md)
 - [Model.EmailListSubscribeResponse](docs/EmailListSubscribeResponse.md)
 - [Model.EmailListsResponse](docs/EmailListsResponse.md)
 - [Model.EmailOrder](docs/EmailOrder.md)
 - [Model.EmailOrdersResponse](docs/EmailOrdersResponse.md)
 - [Model.EmailPerformance](docs/EmailPerformance.md)
 - [Model.EmailPerformanceCustomerHistogram](docs/EmailPerformanceCustomerHistogram.md)
 - [Model.EmailPerformanceCustomerHistogramPeriod](docs/EmailPerformanceCustomerHistogramPeriod.md)
 - [Model.EmailPerformanceDaily](docs/EmailPerformanceDaily.md)
 - [Model.EmailPerformanceResponse](docs/EmailPerformanceResponse.md)
 - [Model.EmailPlan](docs/EmailPlan.md)
 - [Model.EmailPlanAdditional](docs/EmailPlanAdditional.md)
 - [Model.EmailPlanResponse](docs/EmailPlanResponse.md)
 - [Model.EmailPostcardStat](docs/EmailPostcardStat.md)
 - [Model.EmailPostcardTracking](docs/EmailPostcardTracking.md)
 - [Model.EmailPostcardTrackingResponse](docs/EmailPostcardTrackingResponse.md)
 - [Model.EmailSegment](docs/EmailSegment.md)
 - [Model.EmailSegmentArchiveResponse](docs/EmailSegmentArchiveResponse.md)
 - [Model.EmailSegmentCustomer](docs/EmailSegmentCustomer.md)
 - [Model.EmailSegmentCustomersResponse](docs/EmailSegmentCustomersResponse.md)
 - [Model.EmailSegmentDownloadPrepareResponse](docs/EmailSegmentDownloadPrepareResponse.md)
 - [Model.EmailSegmentResponse](docs/EmailSegmentResponse.md)
 - [Model.EmailSegmentsResponse](docs/EmailSegmentsResponse.md)
 - [Model.EmailSendingDomainResponse](docs/EmailSendingDomainResponse.md)
 - [Model.EmailSendingDomainsResponse](docs/EmailSendingDomainsResponse.md)
 - [Model.EmailSettings](docs/EmailSettings.md)
 - [Model.EmailSettingsResponse](docs/EmailSettingsResponse.md)
 - [Model.EmailStat](docs/EmailStat.md)
 - [Model.EmailStatPostcardSummaryRequest](docs/EmailStatPostcardSummaryRequest.md)
 - [Model.EmailStatPostcardSummaryResponse](docs/EmailStatPostcardSummaryResponse.md)
 - [Model.EmailStatSummaryRequest](docs/EmailStatSummaryRequest.md)
 - [Model.EmailStatSummaryResponse](docs/EmailStatSummaryResponse.md)
 - [Model.EmailStepStat](docs/EmailStepStat.md)
 - [Model.EmailStepStatRequest](docs/EmailStepStatRequest.md)
 - [Model.EmailStepStatResponse](docs/EmailStepStatResponse.md)
 - [Model.EmailStepWaitingRequest](docs/EmailStepWaitingRequest.md)
 - [Model.EmailStepWaitingResponse](docs/EmailStepWaitingResponse.md)
 - [Model.EmailTemplate](docs/EmailTemplate.md)
 - [Model.EmailTemplatesResponse](docs/EmailTemplatesResponse.md)
 - [Model.EmailThirdPartyList](docs/EmailThirdPartyList.md)
 - [Model.EmailThirdPartyListImportRequest](docs/EmailThirdPartyListImportRequest.md)
 - [Model.EmailThirdPartyProvider](docs/EmailThirdPartyProvider.md)
 - [Model.EmailThirdPartyProvidersResponse](docs/EmailThirdPartyProvidersResponse.md)
 - [Model.EmailThirdPartyTag](docs/EmailThirdPartyTag.md)
 - [Model.EmailVerifyTokenRequest](docs/EmailVerifyTokenRequest.md)
 - [Model.EmailVerifyTokenResponse](docs/EmailVerifyTokenResponse.md)
 - [Model.EmailVerifyTokenValidateRequest](docs/EmailVerifyTokenValidateRequest.md)
 - [Model.EmailVerifyTokenValidateResponse](docs/EmailVerifyTokenValidateResponse.md)
 - [Model.EmailWebhookEditorValuesResponse](docs/EmailWebhookEditorValuesResponse.md)
 - [Model.Error](docs/Error.md)
 - [Model.ErrorResponse](docs/ErrorResponse.md)
 - [Model.Experiment](docs/Experiment.md)
 - [Model.ExperimentResponse](docs/ExperimentResponse.md)
 - [Model.ExperimentVariation](docs/ExperimentVariation.md)
 - [Model.ExperimentVariationStat](docs/ExperimentVariationStat.md)
 - [Model.ExperimentsResponse](docs/ExperimentsResponse.md)
 - [Model.FileManagerDirectory](docs/FileManagerDirectory.md)
 - [Model.FileManagerFile](docs/FileManagerFile.md)
 - [Model.FileManagerPage](docs/FileManagerPage.md)
 - [Model.FileManagerPageResponse](docs/FileManagerPageResponse.md)
 - [Model.FileManagerUploadRequest](docs/FileManagerUploadRequest.md)
 - [Model.FileManagerUploadUrlResponse](docs/FileManagerUploadUrlResponse.md)
 - [Model.FulfillmentInventory](docs/FulfillmentInventory.md)
 - [Model.FulfillmentShipment](docs/FulfillmentShipment.md)
 - [Model.GeoPoint](docs/GeoPoint.md)
 - [Model.GeocodeRequest](docs/GeocodeRequest.md)
 - [Model.GeocodeResponse](docs/GeocodeResponse.md)
 - [Model.GiftCertificate](docs/GiftCertificate.md)
 - [Model.GiftCertificateCreateRequest](docs/GiftCertificateCreateRequest.md)
 - [Model.GiftCertificateLedgerEntry](docs/GiftCertificateLedgerEntry.md)
 - [Model.GiftCertificateQuery](docs/GiftCertificateQuery.md)
 - [Model.GiftCertificateResponse](docs/GiftCertificateResponse.md)
 - [Model.GiftCertificatesResponse](docs/GiftCertificatesResponse.md)
 - [Model.Group](docs/Group.md)
 - [Model.GroupResponse](docs/GroupResponse.md)
 - [Model.GroupUserMembership](docs/GroupUserMembership.md)
 - [Model.GroupsResponse](docs/GroupsResponse.md)
 - [Model.HTTPHeader](docs/HTTPHeader.md)
 - [Model.HitPageView](docs/HitPageView.md)
 - [Model.HitPageViewMetaData](docs/HitPageViewMetaData.md)
 - [Model.HitSessionStart](docs/HitSessionStart.md)
 - [Model.HitSessionUtm](docs/HitSessionUtm.md)
 - [Model.IntegrationLog](docs/IntegrationLog.md)
 - [Model.IntegrationLogFile](docs/IntegrationLogFile.md)
 - [Model.IntegrationLogLog](docs/IntegrationLogLog.md)
 - [Model.IntegrationLogQueryFilterValues](docs/IntegrationLogQueryFilterValues.md)
 - [Model.IntegrationLogQueryRequest](docs/IntegrationLogQueryRequest.md)
 - [Model.IntegrationLogQueryResponse](docs/IntegrationLogQueryResponse.md)
 - [Model.IntegrationLogResponse](docs/IntegrationLogResponse.md)
 - [Model.IntegrationLogSummary](docs/IntegrationLogSummary.md)
 - [Model.IntegrationLogSummaryQueryRequest](docs/IntegrationLogSummaryQueryRequest.md)
 - [Model.IntegrationLogSummaryQueryResponse](docs/IntegrationLogSummaryQueryResponse.md)
 - [Model.Item](docs/Item.md)
 - [Model.ItemAccounting](docs/ItemAccounting.md)
 - [Model.ItemAmember](docs/ItemAmember.md)
 - [Model.ItemAutoOrder](docs/ItemAutoOrder.md)
 - [Model.ItemAutoOrderStep](docs/ItemAutoOrderStep.md)
 - [Model.ItemAutoOrderStepArbitraryUnitCostSchedule](docs/ItemAutoOrderStepArbitraryUnitCostSchedule.md)
 - [Model.ItemAutoOrderStepGrandfatherPricing](docs/ItemAutoOrderStepGrandfatherPricing.md)
 - [Model.ItemCCBill](docs/ItemCCBill.md)
 - [Model.ItemChannelPartnerMapping](docs/ItemChannelPartnerMapping.md)
 - [Model.ItemChargeback](docs/ItemChargeback.md)
 - [Model.ItemChargebackAddendum](docs/ItemChargebackAddendum.md)
 - [Model.ItemChargebackAdjustmentRequest](docs/ItemChargebackAdjustmentRequest.md)
 - [Model.ItemCheckout](docs/ItemCheckout.md)
 - [Model.ItemContent](docs/ItemContent.md)
 - [Model.ItemContentAssignment](docs/ItemContentAssignment.md)
 - [Model.ItemContentAttribute](docs/ItemContentAttribute.md)
 - [Model.ItemContentMultimedia](docs/ItemContentMultimedia.md)
 - [Model.ItemContentMultimediaThumbnail](docs/ItemContentMultimediaThumbnail.md)
 - [Model.ItemDigitalDelivery](docs/ItemDigitalDelivery.md)
 - [Model.ItemDigitalItem](docs/ItemDigitalItem.md)
 - [Model.ItemDigitalItemPdfMeta](docs/ItemDigitalItemPdfMeta.md)
 - [Model.ItemDigitalItemResponse](docs/ItemDigitalItemResponse.md)
 - [Model.ItemDigitalItemsResponse](docs/ItemDigitalItemsResponse.md)
 - [Model.ItemEbay](docs/ItemEbay.md)
 - [Model.ItemEbayCategorySpecific](docs/ItemEbayCategorySpecific.md)
 - [Model.ItemEbayMarketListing](docs/ItemEbayMarketListing.md)
 - [Model.ItemEbayMarketPlaceAnalysis](docs/ItemEbayMarketPlaceAnalysis.md)
 - [Model.ItemEmailNotifications](docs/ItemEmailNotifications.md)
 - [Model.ItemEnrollment123](docs/ItemEnrollment123.md)
 - [Model.ItemFulfillmentAddon](docs/ItemFulfillmentAddon.md)
 - [Model.ItemGiftCertificate](docs/ItemGiftCertificate.md)
 - [Model.ItemGoogleProductSearch](docs/ItemGoogleProductSearch.md)
 - [Model.ItemIdentifiers](docs/ItemIdentifiers.md)
 - [Model.ItemInstantPaymentNotification](docs/ItemInstantPaymentNotification.md)
 - [Model.ItemInstantPaymentNotifications](docs/ItemInstantPaymentNotifications.md)
 - [Model.ItemInternal](docs/ItemInternal.md)
 - [Model.ItemKitComponent](docs/ItemKitComponent.md)
 - [Model.ItemKitDefinition](docs/ItemKitDefinition.md)
 - [Model.ItemOption](docs/ItemOption.md)
 - [Model.ItemOptionValue](docs/ItemOptionValue.md)
 - [Model.ItemOptionValueAdditionalItem](docs/ItemOptionValueAdditionalItem.md)
 - [Model.ItemOptionValueDigitalItem](docs/ItemOptionValueDigitalItem.md)
 - [Model.ItemPaymentProcessing](docs/ItemPaymentProcessing.md)
 - [Model.ItemPhysical](docs/ItemPhysical.md)
 - [Model.ItemPricing](docs/ItemPricing.md)
 - [Model.ItemPricingTier](docs/ItemPricingTier.md)
 - [Model.ItemPricingTierDiscount](docs/ItemPricingTierDiscount.md)
 - [Model.ItemPricingTierLimit](docs/ItemPricingTierLimit.md)
 - [Model.ItemProperty](docs/ItemProperty.md)
 - [Model.ItemRealtimePricing](docs/ItemRealtimePricing.md)
 - [Model.ItemRelated](docs/ItemRelated.md)
 - [Model.ItemRelatedItem](docs/ItemRelatedItem.md)
 - [Model.ItemReporting](docs/ItemReporting.md)
 - [Model.ItemResponse](docs/ItemResponse.md)
 - [Model.ItemRestriction](docs/ItemRestriction.md)
 - [Model.ItemRestrictionItem](docs/ItemRestrictionItem.md)
 - [Model.ItemRevguard](docs/ItemRevguard.md)
 - [Model.ItemReview](docs/ItemReview.md)
 - [Model.ItemReviews](docs/ItemReviews.md)
 - [Model.ItemSalesforce](docs/ItemSalesforce.md)
 - [Model.ItemShipping](docs/ItemShipping.md)
 - [Model.ItemShippingCase](docs/ItemShippingCase.md)
 - [Model.ItemShippingDestinationMarkup](docs/ItemShippingDestinationMarkup.md)
 - [Model.ItemShippingDestinationRestriction](docs/ItemShippingDestinationRestriction.md)
 - [Model.ItemShippingDistributionCenter](docs/ItemShippingDistributionCenter.md)
 - [Model.ItemShippingMethod](docs/ItemShippingMethod.md)
 - [Model.ItemShippingPackageRequirement](docs/ItemShippingPackageRequirement.md)
 - [Model.ItemTag](docs/ItemTag.md)
 - [Model.ItemTags](docs/ItemTags.md)
 - [Model.ItemTax](docs/ItemTax.md)
 - [Model.ItemTaxExemption](docs/ItemTaxExemption.md)
 - [Model.ItemThirdPartyEmailMarketing](docs/ItemThirdPartyEmailMarketing.md)
 - [Model.ItemVariantItem](docs/ItemVariantItem.md)
 - [Model.ItemVariation](docs/ItemVariation.md)
 - [Model.ItemVariationOption](docs/ItemVariationOption.md)
 - [Model.ItemWishlistMember](docs/ItemWishlistMember.md)
 - [Model.ItemsRequest](docs/ItemsRequest.md)
 - [Model.ItemsResponse](docs/ItemsResponse.md)
 - [Model.KeyValue](docs/KeyValue.md)
 - [Model.LibraryFilterValues](docs/LibraryFilterValues.md)
 - [Model.LibraryFilterValuesResponse](docs/LibraryFilterValuesResponse.md)
 - [Model.LibraryItem](docs/LibraryItem.md)
 - [Model.LibraryItemAccount](docs/LibraryItemAccount.md)
 - [Model.LibraryItemAsset](docs/LibraryItemAsset.md)
 - [Model.LibraryItemAttribute](docs/LibraryItemAttribute.md)
 - [Model.LibraryItemEmail](docs/LibraryItemEmail.md)
 - [Model.LibraryItemPublishedMeta](docs/LibraryItemPublishedMeta.md)
 - [Model.LibraryItemPurchasedMeta](docs/LibraryItemPurchasedMeta.md)
 - [Model.LibraryItemQuery](docs/LibraryItemQuery.md)
 - [Model.LibraryItemResponse](docs/LibraryItemResponse.md)
 - [Model.LibraryItemScreenshot](docs/LibraryItemScreenshot.md)
 - [Model.LibraryItemsResponse](docs/LibraryItemsResponse.md)
 - [Model.LinkedAccount](docs/LinkedAccount.md)
 - [Model.ListSegmentMembership](docs/ListSegmentMembership.md)
 - [Model.LookupRequest](docs/LookupRequest.md)
 - [Model.LookupResponse](docs/LookupResponse.md)
 - [Model.Mailgun](docs/Mailgun.md)
 - [Model.Metric](docs/Metric.md)
 - [Model.Notification](docs/Notification.md)
 - [Model.OauthRevokeSuccessResponse](docs/OauthRevokeSuccessResponse.md)
 - [Model.OauthTokenResponse](docs/OauthTokenResponse.md)
 - [Model.Order](docs/Order.md)
 - [Model.OrderAffiliate](docs/OrderAffiliate.md)
 - [Model.OrderAffiliateLedger](docs/OrderAffiliateLedger.md)
 - [Model.OrderAutoOrder](docs/OrderAutoOrder.md)
 - [Model.OrderBilling](docs/OrderBilling.md)
 - [Model.OrderBuysafe](docs/OrderBuysafe.md)
 - [Model.OrderByTokenQuery](docs/OrderByTokenQuery.md)
 - [Model.OrderChannelPartner](docs/OrderChannelPartner.md)
 - [Model.OrderCheckout](docs/OrderCheckout.md)
 - [Model.OrderCoupon](docs/OrderCoupon.md)
 - [Model.OrderDigitalItem](docs/OrderDigitalItem.md)
 - [Model.OrderDigitalOrder](docs/OrderDigitalOrder.md)
 - [Model.OrderEdi](docs/OrderEdi.md)
 - [Model.OrderEdiDocument](docs/OrderEdiDocument.md)
 - [Model.OrderEdiDocumentsResponse](docs/OrderEdiDocumentsResponse.md)
 - [Model.OrderFormat](docs/OrderFormat.md)
 - [Model.OrderFormatResponse](docs/OrderFormatResponse.md)
 - [Model.OrderFraudScore](docs/OrderFraudScore.md)
 - [Model.OrderGift](docs/OrderGift.md)
 - [Model.OrderGiftCertificate](docs/OrderGiftCertificate.md)
 - [Model.OrderInternal](docs/OrderInternal.md)
 - [Model.OrderInvoiceResponse](docs/OrderInvoiceResponse.md)
 - [Model.OrderItem](docs/OrderItem.md)
 - [Model.OrderItemEdi](docs/OrderItemEdi.md)
 - [Model.OrderItemEdiIdentification](docs/OrderItemEdiIdentification.md)
 - [Model.OrderItemEdiLot](docs/OrderItemEdiLot.md)
 - [Model.OrderItemOption](docs/OrderItemOption.md)
 - [Model.OrderItemOptionFileAttachment](docs/OrderItemOptionFileAttachment.md)
 - [Model.OrderItemProperty](docs/OrderItemProperty.md)
 - [Model.OrderItemTag](docs/OrderItemTag.md)
 - [Model.OrderLinkedShipment](docs/OrderLinkedShipment.md)
 - [Model.OrderMarketing](docs/OrderMarketing.md)
 - [Model.OrderPackingSlipResponse](docs/OrderPackingSlipResponse.md)
 - [Model.OrderPayment](docs/OrderPayment.md)
 - [Model.OrderPaymentCheck](docs/OrderPaymentCheck.md)
 - [Model.OrderPaymentCreditCard](docs/OrderPaymentCreditCard.md)
 - [Model.OrderPaymentECheck](docs/OrderPaymentECheck.md)
 - [Model.OrderPaymentInsurance](docs/OrderPaymentInsurance.md)
 - [Model.OrderPaymentPurchaseOrder](docs/OrderPaymentPurchaseOrder.md)
 - [Model.OrderPaymentTransaction](docs/OrderPaymentTransaction.md)
 - [Model.OrderPaymentTransactionDetail](docs/OrderPaymentTransactionDetail.md)
 - [Model.OrderPointOfSale](docs/OrderPointOfSale.md)
 - [Model.OrderProcessPaymentRequest](docs/OrderProcessPaymentRequest.md)
 - [Model.OrderProcessPaymentResponse](docs/OrderProcessPaymentResponse.md)
 - [Model.OrderProperty](docs/OrderProperty.md)
 - [Model.OrderQuery](docs/OrderQuery.md)
 - [Model.OrderQueryBatch](docs/OrderQueryBatch.md)
 - [Model.OrderQuote](docs/OrderQuote.md)
 - [Model.OrderReason](docs/OrderReason.md)
 - [Model.OrderRefundableResponse](docs/OrderRefundableResponse.md)
 - [Model.OrderReplacement](docs/OrderReplacement.md)
 - [Model.OrderReplacementItem](docs/OrderReplacementItem.md)
 - [Model.OrderReplacementResponse](docs/OrderReplacementResponse.md)
 - [Model.OrderResponse](docs/OrderResponse.md)
 - [Model.OrderSalesforce](docs/OrderSalesforce.md)
 - [Model.OrderShipping](docs/OrderShipping.md)
 - [Model.OrderSummary](docs/OrderSummary.md)
 - [Model.OrderTag](docs/OrderTag.md)
 - [Model.OrderTaxes](docs/OrderTaxes.md)
 - [Model.OrderTokenResponse](docs/OrderTokenResponse.md)
 - [Model.OrderTrackingNumberDetail](docs/OrderTrackingNumberDetail.md)
 - [Model.OrderTrackingNumberDetails](docs/OrderTrackingNumberDetails.md)
 - [Model.OrderTransactionalMerchantNote](docs/OrderTransactionalMerchantNote.md)
 - [Model.OrderUtm](docs/OrderUtm.md)
 - [Model.OrdersResponse](docs/OrdersResponse.md)
 - [Model.Permission](docs/Permission.md)
 - [Model.PointOfSaleLocation](docs/PointOfSaleLocation.md)
 - [Model.PointOfSaleReader](docs/PointOfSaleReader.md)
 - [Model.PointOfSaleRegister](docs/PointOfSaleRegister.md)
 - [Model.PricingTier](docs/PricingTier.md)
 - [Model.PricingTierNotification](docs/PricingTierNotification.md)
 - [Model.PricingTiersResponse](docs/PricingTiersResponse.md)
 - [Model.Property](docs/Property.md)
 - [Model.PublishLibraryItemRequest](docs/PublishLibraryItemRequest.md)
 - [Model.RegisterAffiliateClickRequest](docs/RegisterAffiliateClickRequest.md)
 - [Model.RegisterAffiliateClickResponse](docs/RegisterAffiliateClickResponse.md)
 - [Model.Report](docs/Report.md)
 - [Model.ReportAuth](docs/ReportAuth.md)
 - [Model.ReportAuthResponse](docs/ReportAuthResponse.md)
 - [Model.ReportDataSet](docs/ReportDataSet.md)
 - [Model.ReportDataSetColumn](docs/ReportDataSetColumn.md)
 - [Model.ReportDataSetPage](docs/ReportDataSetPage.md)
 - [Model.ReportDataSetPageResponse](docs/ReportDataSetPageResponse.md)
 - [Model.ReportDataSetQuery](docs/ReportDataSetQuery.md)
 - [Model.ReportDataSetResponse](docs/ReportDataSetResponse.md)
 - [Model.ReportDataSetRow](docs/ReportDataSetRow.md)
 - [Model.ReportDataSetSchema](docs/ReportDataSetSchema.md)
 - [Model.ReportDataSource](docs/ReportDataSource.md)
 - [Model.ReportDataSourceSchema](docs/ReportDataSourceSchema.md)
 - [Model.ReportDryRunQueriesRequest](docs/ReportDryRunQueriesRequest.md)
 - [Model.ReportDryRunQueriesResponse](docs/ReportDryRunQueriesResponse.md)
 - [Model.ReportDryRunQueryResult](docs/ReportDryRunQueryResult.md)
 - [Model.ReportExecuteQueriesRequest](docs/ReportExecuteQueriesRequest.md)
 - [Model.ReportFilter](docs/ReportFilter.md)
 - [Model.ReportFilterConnection](docs/ReportFilterConnection.md)
 - [Model.ReportPage](docs/ReportPage.md)
 - [Model.ReportPageVisualization](docs/ReportPageVisualization.md)
 - [Model.ReportPageVisualizationDimension](docs/ReportPageVisualizationDimension.md)
 - [Model.ReportPageVisualizationMetric](docs/ReportPageVisualizationMetric.md)
 - [Model.ReportResponse](docs/ReportResponse.md)
 - [Model.ReportWebsocketEvent](docs/ReportWebsocketEvent.md)
 - [Model.ReportsResponse](docs/ReportsResponse.md)
 - [Model.ResponseMetadata](docs/ResponseMetadata.md)
 - [Model.ResultSet](docs/ResultSet.md)
 - [Model.RulerValidationRequest](docs/RulerValidationRequest.md)
 - [Model.RulerValidationResponse](docs/RulerValidationResponse.md)
 - [Model.ScreenRecording](docs/ScreenRecording.md)
 - [Model.ScreenRecordingAdPlatform](docs/ScreenRecordingAdPlatform.md)
 - [Model.ScreenRecordingFilter](docs/ScreenRecordingFilter.md)
 - [Model.ScreenRecordingFilterGeoDistance](docs/ScreenRecordingFilterGeoDistance.md)
 - [Model.ScreenRecordingFilterIpSearch](docs/ScreenRecordingFilterIpSearch.md)
 - [Model.ScreenRecordingFilterPageView](docs/ScreenRecordingFilterPageView.md)
 - [Model.ScreenRecordingFilterPageViewEvent](docs/ScreenRecordingFilterPageViewEvent.md)
 - [Model.ScreenRecordingFilterPageViewEventParam](docs/ScreenRecordingFilterPageViewEventParam.md)
 - [Model.ScreenRecordingFilterPageViewParam](docs/ScreenRecordingFilterPageViewParam.md)
 - [Model.ScreenRecordingFilterPageViewReferrerParam](docs/ScreenRecordingFilterPageViewReferrerParam.md)
 - [Model.ScreenRecordingFilterRangeBigDecimal](docs/ScreenRecordingFilterRangeBigDecimal.md)
 - [Model.ScreenRecordingFilterRangeDate](docs/ScreenRecordingFilterRangeDate.md)
 - [Model.ScreenRecordingFilterRangeInteger](docs/ScreenRecordingFilterRangeInteger.md)
 - [Model.ScreenRecordingFilterStringSearch](docs/ScreenRecordingFilterStringSearch.md)
 - [Model.ScreenRecordingFilterValues](docs/ScreenRecordingFilterValues.md)
 - [Model.ScreenRecordingFilterValuesEvent](docs/ScreenRecordingFilterValuesEvent.md)
 - [Model.ScreenRecordingFilterValuesEventParams](docs/ScreenRecordingFilterValuesEventParams.md)
 - [Model.ScreenRecordingFilterValuesPageParam](docs/ScreenRecordingFilterValuesPageParam.md)
 - [Model.ScreenRecordingFilterValuesPageView](docs/ScreenRecordingFilterValuesPageView.md)
 - [Model.ScreenRecordingHeatmap](docs/ScreenRecordingHeatmap.md)
 - [Model.ScreenRecordingHeatmapIndexRequest](docs/ScreenRecordingHeatmapIndexRequest.md)
 - [Model.ScreenRecordingHeatmapIndexResponse](docs/ScreenRecordingHeatmapIndexResponse.md)
 - [Model.ScreenRecordingHeatmapRequest](docs/ScreenRecordingHeatmapRequest.md)
 - [Model.ScreenRecordingHeatmapReset](docs/ScreenRecordingHeatmapReset.md)
 - [Model.ScreenRecordingHeatmapResponse](docs/ScreenRecordingHeatmapResponse.md)
 - [Model.ScreenRecordingHeatmapUrl](docs/ScreenRecordingHeatmapUrl.md)
 - [Model.ScreenRecordingMerchantNotesRequest](docs/ScreenRecordingMerchantNotesRequest.md)
 - [Model.ScreenRecordingMultifield](docs/ScreenRecordingMultifield.md)
 - [Model.ScreenRecordingPageView](docs/ScreenRecordingPageView.md)
 - [Model.ScreenRecordingPageViewDataResponse](docs/ScreenRecordingPageViewDataResponse.md)
 - [Model.ScreenRecordingPageViewEvent](docs/ScreenRecordingPageViewEvent.md)
 - [Model.ScreenRecordingPageViewEventParameter](docs/ScreenRecordingPageViewEventParameter.md)
 - [Model.ScreenRecordingPageViewParameter](docs/ScreenRecordingPageViewParameter.md)
 - [Model.ScreenRecordingQueryRequest](docs/ScreenRecordingQueryRequest.md)
 - [Model.ScreenRecordingQueryResponse](docs/ScreenRecordingQueryResponse.md)
 - [Model.ScreenRecordingResponse](docs/ScreenRecordingResponse.md)
 - [Model.ScreenRecordingSegment](docs/ScreenRecordingSegment.md)
 - [Model.ScreenRecordingSegmentResponse](docs/ScreenRecordingSegmentResponse.md)
 - [Model.ScreenRecordingSegmentsResponse](docs/ScreenRecordingSegmentsResponse.md)
 - [Model.ScreenRecordingSettings](docs/ScreenRecordingSettings.md)
 - [Model.ScreenRecordingSettingsResponse](docs/ScreenRecordingSettingsResponse.md)
 - [Model.ScreenRecordingStoreFront](docs/ScreenRecordingStoreFront.md)
 - [Model.ScreenRecordingTagsRequest](docs/ScreenRecordingTagsRequest.md)
 - [Model.ScreenRecordingTagsResponse](docs/ScreenRecordingTagsResponse.md)
 - [Model.ScreenRecordingUserAgent](docs/ScreenRecordingUserAgent.md)
 - [Model.ScreenRecordingUserAgentDevice](docs/ScreenRecordingUserAgentDevice.md)
 - [Model.ScreenRecordingUserAgentOS](docs/ScreenRecordingUserAgentOS.md)
 - [Model.ScreenRecordingUserProperty](docs/ScreenRecordingUserProperty.md)
 - [Model.ScreenshotsResponse](docs/ScreenshotsResponse.md)
 - [Model.SelfConfig](docs/SelfConfig.md)
 - [Model.SimpleValue](docs/SimpleValue.md)
 - [Model.SingleSignOnAuthorizeRequest](docs/SingleSignOnAuthorizeRequest.md)
 - [Model.SingleSignOnAuthorizeResponse](docs/SingleSignOnAuthorizeResponse.md)
 - [Model.SingleSignOnTokenRequest](docs/SingleSignOnTokenRequest.md)
 - [Model.SingleSignOnTokenResponse](docs/SingleSignOnTokenResponse.md)
 - [Model.SovosConfig](docs/SovosConfig.md)
 - [Model.StateProvince](docs/StateProvince.md)
 - [Model.StepWaiting](docs/StepWaiting.md)
 - [Model.StoreFront](docs/StoreFront.md)
 - [Model.StoreFrontsResponse](docs/StoreFrontsResponse.md)
 - [Model.TaxCity](docs/TaxCity.md)
 - [Model.TaxCountry](docs/TaxCountry.md)
 - [Model.TaxCountryCode](docs/TaxCountryCode.md)
 - [Model.TaxCounty](docs/TaxCounty.md)
 - [Model.TaxJarConfig](docs/TaxJarConfig.md)
 - [Model.TaxPostalCode](docs/TaxPostalCode.md)
 - [Model.TaxProviderActivateResult](docs/TaxProviderActivateResult.md)
 - [Model.TaxProviderAvalara](docs/TaxProviderAvalara.md)
 - [Model.TaxProviderAvalaraCompaniesResult](docs/TaxProviderAvalaraCompaniesResult.md)
 - [Model.TaxProviderAvalaraCompany](docs/TaxProviderAvalaraCompany.md)
 - [Model.TaxProviderSelf](docs/TaxProviderSelf.md)
 - [Model.TaxProviderSelfCountriesResponse](docs/TaxProviderSelfCountriesResponse.md)
 - [Model.TaxProviderSelfRegionsResponse](docs/TaxProviderSelfRegionsResponse.md)
 - [Model.TaxProviderSovos](docs/TaxProviderSovos.md)
 - [Model.TaxProviderTaxJar](docs/TaxProviderTaxJar.md)
 - [Model.TaxProviderTestResult](docs/TaxProviderTestResult.md)
 - [Model.TaxProviderUltraCart](docs/TaxProviderUltraCart.md)
 - [Model.TaxProviderUltraCartState](docs/TaxProviderUltraCartState.md)
 - [Model.TaxProvidersResponse](docs/TaxProvidersResponse.md)
 - [Model.TaxState](docs/TaxState.md)
 - [Model.TaxStateCode](docs/TaxStateCode.md)
 - [Model.TempMultimedia](docs/TempMultimedia.md)
 - [Model.TempMultimediaResponse](docs/TempMultimediaResponse.md)
 - [Model.ThumbnailParametersRequest](docs/ThumbnailParametersRequest.md)
 - [Model.ThumbnailParametersResponse](docs/ThumbnailParametersResponse.md)
 - [Model.TransactionEmail](docs/TransactionEmail.md)
 - [Model.TransactionEmailListResponse](docs/TransactionEmailListResponse.md)
 - [Model.TransactionEmailOption](docs/TransactionEmailOption.md)
 - [Model.TransactionEmailResponse](docs/TransactionEmailResponse.md)
 - [Model.Twilio](docs/Twilio.md)
 - [Model.TwilioResponse](docs/TwilioResponse.md)
 - [Model.TwiliosResponse](docs/TwiliosResponse.md)
 - [Model.UltraCartConfig](docs/UltraCartConfig.md)
 - [Model.UploadCouponCodesRequest](docs/UploadCouponCodesRequest.md)
 - [Model.UploadCouponCodesResponse](docs/UploadCouponCodesResponse.md)
 - [Model.User](docs/User.md)
 - [Model.UserGroupMembership](docs/UserGroupMembership.md)
 - [Model.UserLogin](docs/UserLogin.md)
 - [Model.UserLoginsResponse](docs/UserLoginsResponse.md)
 - [Model.UserResponse](docs/UserResponse.md)
 - [Model.UsersResponse](docs/UsersResponse.md)
 - [Model.VerificationRecord](docs/VerificationRecord.md)
 - [Model.Warning](docs/Warning.md)
 - [Model.Webhook](docs/Webhook.md)
 - [Model.WebhookEventCategory](docs/WebhookEventCategory.md)
 - [Model.WebhookEventSubscription](docs/WebhookEventSubscription.md)
 - [Model.WebhookLog](docs/WebhookLog.md)
 - [Model.WebhookLogResponse](docs/WebhookLogResponse.md)
 - [Model.WebhookLogSummariesResponse](docs/WebhookLogSummariesResponse.md)
 - [Model.WebhookLogSummary](docs/WebhookLogSummary.md)
 - [Model.WebhookResponse](docs/WebhookResponse.md)
 - [Model.WebhookSampleRequest](docs/WebhookSampleRequest.md)
 - [Model.WebhookSampleRequestResponse](docs/WebhookSampleRequestResponse.md)
 - [Model.WebhooksResponse](docs/WebhooksResponse.md)
 - [Model.Weight](docs/Weight.md)


## Documentation for Authorization


### ultraCartBrowserApiKey

- **Type**: API key

- **API key parameter name**: x-ultracart-browser-key
- **Location**: HTTP header


### ultraCartOauth


- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://secure.ultracart.com/rest/v2/oauth/authorize
- **Scopes**: 
  - affiliate_read: Allows you to read affiliate information.
  - affiliate_write: Allows you to write affiliate information.
  - auto_order_read: Allows you to read auto order information.
  - auto_order_write: Allows you to write auto order information.
  - channel_partner_read: Allows you to read channel partner information.
  - channel_partner_write: Allows you to write channel partner information.
  - chargeback_read: Allows you to read chargeback information.
  - chargeback_write: Allows you to write chargeback information.
  - checkout_read: Allows you to read checkout information.
  - checkout_write: Allows you to write checkout information.
  - configuration_read: Allows you to read configuration information.
  - configuration_write: Allows you to write configuration information.
  - conversation_read: Allows you to read conversation information.
  - conversation_write: Allows you to write conversation information.
  - coupon_read: Allows you to read coupon information.
  - coupon_write: Allows you to write coupon information.
  - customer_read: Allows you to read customer information.
  - customer_write: Allows you to write customer information.
  - fulfillment_read: Allows you to read fulfillment information.
  - fulfillment_write: Allows you to write fulfillment information.
  - gift_certificate_read: Allows you to read gift certificate information.
  - gift_certificate_write: Allows you to write gift certificate information.
  - integration_log_read: Allows you to read integration log information.
  - integration_log_write: Allows you to write integration log information.
  - order_read: Allows you to read order information.
  - order_write: Allows you to write order information.
  - item_read: Allows you to read item information.
  - item_write: Allows you to write item information.
  - storefront_read: Allows you to read storefront information.
  - storefront_write: Allows you to write storefront information.
  - tax_read: Allows you to read tax configuration information.
  - tax_write: Allows you to write tax configuration information.
  - webhook_read: Allows you to read webhook information.
  - webhook_write: Allows you to write webhook information.
  - ultrabooks_read: 1 of 2 required to use UltraBooks
  - ultrabooks_write: 2 of 2 required to use UltraBooks
  - user_read: Allows you to read user information.
  - user_write: Allows you to write user information.


### ultraCartSimpleApiKey

- **Type**: API key

- **API key parameter name**: x-ultracart-simple-key
- **Location**: HTTP header




# CHANGE LOG
Not every change is committed to every SDK.

| Version | Date | Comments |
| --: | :-: | --- |
| 4.0.145 | 04/10/2023 | data warehouse internal dev |
| 4.0.144 | 03/29/2023 | internal development |
| 4.0.143 | 03/22/2023 | data warehouse internal dev |
| 4.0.142 | 03/22/2023 | dw initial framework |
| 4.0.141 | 03/22/2023 | order api - refundable response added manual_because_multiple_charges boolean field |
| 4.0.140 | 03/21/2023 | order api - new stage named Hold |
| 4.0.139 | 03/14/2023 | order.getOrderEdiDocuments |
| 4.0.138 | 03/01/2023 | convo - add sentiment record to conversation obj |
| 4.0.137 | 02/22/2023 | convo - customer initiated flag on engagement |
| 4.0.136 | 02/20/2023 | refund reasons |
| 4.0.135 | 02/17/2023 | convo api - smsUnsubscribeConversation method |
| 4.0.134 | 02/15/2023 | added auto order sorting by next_shipment_dts |
| 4.0.133 | 02/10/2023 | convo - add storefront_host_name to search request |
| 4.0.132 | 02/07/2023 | convo - new event for when a customer joins a queue |
| 4.0.131 | 02/07/2023 | convo - new event for when a customer joins a queue |
| 4.0.130 | 02/06/2023 | convo - add conversation_arn to ConversationWebsocketMessage |
| 4.0.129 | 02/01/2023 | convo - agent profile get/update methods |
| 4.0.128 | 01/27/2023 | convo - added event_engage_customer property to message |
| 4.0.127 | 01/27/2023 | conversations - getLocationsForEngagement method |
| 4.0.126-RC | 01/26/2023 | typo in ConversationWebsocketMessage |
| 4.0.125-RC | 01/26/2023 | conversation - added message type of engagement prompt |
| 4.0.124-RC | 01/25/2023 | convo event for engage customer |
| 4.0.123-RC | 01/25/2023 | order api method generateInvoice |
| 4.0.122-RC | 01/24/2023 | auto order - cancel minimum and change balance options |
| 4.0.121-RC | 01/23/2023 | conversation - method to fetch single engagement record |
| 4.0.120-RC | 01/19/2023 | added skip_on_rebill field to coupon object |
| 4.0.119-RC | 01/19/2023 | convo - getConversationPermissions added |
| 4.0.118-RC | 01/18/2023 | conversation get dept member list method added |
| 4.0.117-RC | 01/18/2023 | conversation dept members |
| 4.0.116-RC | 01/18/2023 | channel partner ship to pref desc field |
| 4.0.115-RC | 01/17/2023 | changed convo webchat constant |
| 4.0.114-RC | 01/17/2023 | support for checkout item properties |
| 4.0.113-RC | 01/14/2023 | add external_id to the point of sale location object |
| 4.0.112-RC | 01/13/2023 | channel - ops to manage ship to prefs |
| 4.0.111-RC | 01/11/2023 | conversations - adjust search results to return multiple convo summaries |
| 4.0.110-RC | 01/10/2023 | add method to query integration log record by oid |
| 4.0.109-RC | 01/10/2023 | bug fix for typescript enum error due to apost |
| 4.0.108-RC | 01/10/2023 | integration log tracking of associated auto order oids |
| 4.0.107-RC | 01/06/2023 | conversation search response object bug fix |
| 4.0.106-RC | 01/05/2023 | communications - added maximum_enrolled flag on flow object |
| 4.0.105-RC | 01/03/2023 | conversation events for party leave and join |
| 4.0.104-RC | 01/03/2023 | order point of sale details |
| 4.0.103-RC | 12/27/2022 | additional loyalty related coupons |
| 4.0.102-RC | 12/21/2022 | conversation development |
| 4.0.101-RC | 12/20/2022 | conversation engagement update |
| 4.0.100-RC | 12/20/2022 | conversation engagement update |
| 4.0.99-RC | 12/15/2022 | conversation search - added start date filtering |
| 4.0.98-RC | 12/15/2022 | conversation searching |
| 4.0.97-RC | 12/13/2022 | conversations - add email and sms_phone to participant object |
| 4.0.96-RC | 12/09/2022 | conversations - message translation |
| 4.0.95-RC | 12/08/2022 | conversation canned messages |
| 4.0.94-RC | 12/08/2022 | communications - expose the rebuild percentage |
| 4.0.93-RC | 12/06/2022 | convo - add session_start_dts to webchat context, cart - add customer_profile.signup_dts |
| 4.0.92-RC | 12/06/2022 | customer api - expose edi information and editor values |
| 4.0.91-RC | 12/02/2022 | conversations - customer last unresponded dts |
| 4.0.90-RC | 11/30/2022 | conversations - add order and auto order information to webchat context |
| 4.0.89-RC | 11/30/2022 | order item - addl fields for linking kits to kit components |
| 4.0.88-RC | 11/29/2022 | converstation marked convo read method |
| 4.0.87-RC | 11/21/2022 | coupon - addl optional minimums for percent off msrp items coupon |
| 4.0.86-RC | 11/21/2022 | conversation context method |
| 4.0.85-RC | 11/21/2022 | adjusted conversation event model |
| 4.0.84-RC | 11/15/2022 | conversation methods bug fix |
| 4.0.83-RC | 11/15/2022 | conversations - enw events for add coupon and items |
| 4.0.82-RC | 11/15/2022 | order api new method is order refundable |
| 4.0.81-RC | 11/15/2022 | increase order property length to 10k char |
| 4.0.80-RC | 11/14/2022 | conversations - add allowed values for update agent status |
| 4.0.79-RC | 11/09/2022 | conversations - add an enum of event typing |
| 4.0.78-RC | 11/04/2022 | new coupon type percent based on msrp |
| 4.0.77-RC | 10/31/2022 | communication bug fix on dup annonation |
| 4.0.76-RC | 10/31/2022 | communications - addl statistics on EmailStepStat object |
| 4.0.75-RC | 10/26/2022 | esp - methods for sms testing |
| 4.0.74-RC | 10/17/2022 | conversations - add last_interactive_message_dts |
| 4.0.73-RC | 10/07/2022 | bug fix for digital items response |
| 4.0.72-RC | 10/05/2022 | storefront rest file cdn icon urls |
| 4.0.71-RC | 10/04/2022 | bug fix for new storefront file mgr |
| 4.0.70-RC | 09/29/2022 | page_paths search category for search2 method |
| 4.0.69-RC | 09/29/2022 | storefront file mgr calls tweaks |
| 4.0.68-RC | 09/29/2022 | storefront methods for file manager ui |
| 4.0.67-RC | 09/27/2022 | added digital library call for unassociated content |
| 4.0.66-RC | 09/22/2022 | digital item mgmt testing |
| 4.0.65-RC | 09/22/2022 | testing digital file mgmt calls |
| 4.0.64-RC | 09/19/2022 | conversations pagination |
| 4.0.63-RC | 09/13/2022 | storefront comms - postcard tracking |
| 4.0.62-RC | 09/12/2022 | storefront comm - send back reviews.io configured flag on getEmailSettings |
| 4.0.61-RC | 09/07/2022 | sf comms - using aws event ruler for bigquery segmentation validation |
| 4.0.60-RC | 09/02/2022 | customer editor added loyal ledger descriptions |
| 4.0.59-RC | 08/30/2022 | storefront comm fields for sms configuration |
| 4.0.58-RC | 08/26/2022 | postcard address fields for comm sequence testing |
| 4.0.57-RC | 08/22/2022 | exposing individual reviews within item.review object |
| 4.0.56-RC | 08/19/2022 | order api - added cell phone fields for sms |
| 4.0.55-RC | 08/12/2022 | internal code to allow merchant login as customer |
| 4.0.54-RC | 08/11/2022 | fix entry_dts type on gift certificate ledger |
| 4.0.53-RC | 08/10/2022 | conversation event refactoring |
| 4.0.52-RC | 08/05/2022 | conversation adjustments for ES integration |
| 4.0.51-RC | 08/05/2022 | conversations query by medium and stats fixes |
| 4.0.50-RC | 08/03/2022 | conversation summary participants |
| 4.0.49-RC | 08/03/2022 | more conversation events |
| 4.0.48-RC | 08/02/2022 | storefront communication sequence test method |
| 4.0.47-RC | 08/01/2022 | conversation event refinement |
| 4.0.46-RC | 07/29/2022 | conversation development |
| 4.0.45-RC | 07/28/2022 | conversation bug fixes |
| 4.0.44-RC | 07/28/2022 | conversation message upload keys property |
| 4.0.43-RC | 07/26/2022 | conversations - queue statistics |
| 4.0.42-RC | 07/25/2022 | conversation development |
| 4.0.41-RC | 07/25/2022 | conversations bug fixes |
| 4.0.40-RC | 07/25/2022 | conversations - add a websocket message model |
| 4.0.39-RC | 07/21/2022 | conversation response types improvements |
| 4.0.38-RC | 07/21/2022 | conversation bugfix for poor response objects |
| 4.0.37-RC | 07/20/2022 | conversation participant name added |
| 4.0.36-RC | 07/18/2022 | twilio dev |
| 4.0.35-RC | 07/14/2022 | Add channel storefront_oid to the customer activity record |
| 4.0.34-RC | 07/11/2022 | Customer API - mergeCustomer method |
| 4.0.33-RC | 07/05/2022 | docs update |
| 4.0.32-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.31-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.30-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.29-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.28-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.27-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.26-RC | 06/24/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.25-RC | 06/23/2022 | removed unneeded consumes declarations on several api calls (yaml fix) |
| 4.0.24-RC | 06/23/2022 | automation test |
| 4.0.23-RC | 06/23/2022 | automation test |
| 4.0.22-RC | 06/23/2022 | v4 automation testing - not production ready |
| 4.0.21-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.20-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.19-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.18-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.17-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.16-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.15-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.14-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.13-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.12-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.11-RC | 06/22/2022 | v4 automation testing - not production ready |
| 4.0.10-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.9-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.8-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.7-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.6-RC | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.5 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.4 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.3 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.2 | 06/21/2022 | v4 automation testing - not production ready |
| 4.0.1-RC | 06/21/2022 | ChannelPartnerApi.estimateShipping |
| 3.10.14 | 06/16/2022 | added createEmailSendingDomain2 to support additional MTAs |
| 3.10.13 | 06/16/2022 | renamed latest method to avoid conflict between customer profile search and storefront search |
| 3.10.12 | 06/16/2022 | Customer profile search method to look up tags |
| 3.10.11 | 06/10/2022 | esp segment 3rd party sync add/remove tag fields |
| 3.10.10 | 06/06/2022 | storefront communication options for syncing to third party provider list |
| 3.10.9 | 06/01/2022 | bug fixes for customer profile store credit |
| 3.10.8 | 05/27/2022 | customer store credit |
| 3.10.7 | 05/23/2022 | add internal gift cert to order summary, addl provider info for storefront comm |
| 3.10.6 | 05/23/2022 | add internal gift cert to order summary, addl provider info for storefront comm |
| 3.10.5 | 05/20/2022 | dependabot on java gson version |
| 3.10.4 | 05/20/2022 | dependabot on java gson |
| 3.10.3 | 05/20/2022 | OrderApi.generatePackingSkip calls had wrong return type |
| 3.10.2 | 05/12/2022 | ChannelPartnerApi renamed one of the delete methods |
| 3.10.1 | 05/12/2022 | ChannelPartnerApi added orderId to import response obj |
| 3.10.0 | 05/10/2022 | beta release of ChannelPartnerApi |
| 3.9.8 | 04/26/2022 | OrderApi.duplicateOrder |
| 3.9.7 | 04/25/2022 | integration logs method for zpl to pdf conversion |
| 3.9.6 | 04/25/2022 | storefront communications email magic link setting |
| 3.9.5 | 04/14/2022 | postcard screenshot bug fixes |
| 3.9.4 | 04/13/2022 | Added spf DNS record to the sending domain object |
| 3.9.3 | 04/06/2022 | fix return object on send webhook test method |
| 3.9.2 | 04/04/2022 | user.email field extended and postcard screenshot fields |
| 3.9.1 | 03/03/2022 | javascript sdk package.json bug fix |
| 3.9.0 | 03/03/2022 | removed  ultra_cart_rest_api_v2.d.ts from javascript sdk because typescript sdk exists now |
| 3.8.8 | 03/02/2022 | bug fix for ruby sdk, uri.escape deprecated in 3.x |
| 3.8.7 | 03/02/2022 | bug fix for ruby sdk, uri.escape deprecated in 3.x |
| 3.8.6 | 03/02/2022 | bug fix for ruby sdk, uri.escape deprecated in 3.x |
| 3.8.5 | 02/25/2022 | new coupon for fixed cost shipping method |
| 3.8.2 | 02/16/2022 | create gift certificate method was missing email |
| 3.8.1 | 02/16/2022 | auto order item level pause flag |
| 3.8.0 | 02/16/2022 | gift certificate api (testing) |
| 3.7.38 | 02/15/2022 | gift certificate api (currently in testing) |
| 3.6.38 | 02/07/2022 | Exposed auto order logs |
| 3.6.37 | 02/04/2022 | insurance type for insurance payments |
| 3.6.36 | 12/29/2021 | Mail actual post card flag added to test method |
| 3.6.35 | 12/14/2021 | Add cancel_auto_order option to the accounts receivable retry configuration |
| 3.6.34 | 12/14/2021 | add evening phone E.164 fields to order billing/shipping objects |
| 3.6.33 | 12/13/2021 | automation testing |
| 3.6.32 | 12/10/2021 | testing automation - message 4 |
| 3.6.25 | 12/06/2021 | sdk automation testing.  no changes to actual sdk | 
| 3.6.24 | 11/30/2021 | return items_invalid_for_coupons for CouponResponse object to drive UI warnings | 
| 3.6.23 | 11/29/2021 | Item auto order prohibit cards that expire in months setting. | 
| 3.6.22 | 11/23/2021 | new storefront methods for twilio configuration | 
| 3.6.21 | 11/08/2021 | item shipping distribution center level CostOfGoodsSold | 
| 3.6.20 | 11/05/2021 | additional item auto order step types  | 
| 3.6.19 | 10/05/2021 | item fulfillment add ons  | 
| 3.6.18 | 09/30/2021 | terms if auto order flag added  | 
| 3.6.16 | 09/30/2021 | item exclude from sitemap field  | 
| 3.6.15 | 09/28/2021 | added refund_claim_id to insurance object  | 
| 3.6.14 | 09/21/2021 | configuration api fix.  the echeck test methods were attached to the paper check object  | 
| 3.6.13 | 09/20/2021 | expose EasyPost tracker id if available on shipment tracking details  | 
| 3.6.12 | 09/20/2021 | fix method for getCouponsByQuery to be POST instead of GET since it uses a JSON body  | 
| 3.6.11 | 09/13/2021 | fix for CouponApi, broke due to inadvertent parameter inclusion   | 
| 3.6.10 | 09/09/2021 | added constants for Google Shopping payment method (still in development)  | 
| 3.6.9 | 09/07/2021 | customer profile editor values have new list of state optional countries  | 
| 3.6.8 | 08/31/2021 | coupon query field to allow merchant code and description to be searched  | 
| 3.6.7 | 08/27/2021 | customer profile affiliate information now contains affiliate first and last name | 
| 3.6.6 | 08/26/2021 | configuration api - more field changes for UI | 
| 3.6.5 | 08/25/2021 | configuration api - removed some internal fields from sdk | 
| 3.6.4 | 08/24/2021 | configuration api - new payment method named insurance | 
| 3.6.1 | 08/23/2021 | configuration api - enum problems, also added order.item.tracking_number to support line item tracking numbers | 
| 3.6.0 | 08/19/2021 | coupon api - changed tieredAmountOffItem to support mulitple items | 
| 3.5.3 | 08/18/2021 | configuration api - added credit card rate to UltraCart Payments object | 
| 3.5.1 | 08/11/2021 | email webhook test method | 
| 3.5.0 | 08/11/2021 | RestOrderChannelPartner.store_completed was incorrectly defaulting to true | 
| 3.4.13 | 08/10/2021 | configuration api - changed some field types form string to number | 
| 3.4.12 | 08/10/2021 | email engine - added webhook editor values for internal ui  | 
| 3.4.9 | 08/05/2021 | configuration api - updated annotations for method names | 
| 3.4.8 | 08/04/2021 | configuration api - payments config refactoring | 
| 3.4.7 | 08/04/2021 | esp folders for lists/segments | 
| 3.4.5 | 08/03/2021 | configuration api bug fix for a bad response object on updateRotatingTransactionGateway | 
| 3.4.3 | 08/03/2021 | package tracking - add event_iso_date and event_timezone_id | 
| 3.4.2 | 07/29/2021 | bug fixes for new configuration api | 
| 3.4.1 | 07/29/2021 | bug fixes for new configuration api | 
| 3.4.0 | 07/29/2021 | added new configuration api (not live yet. sdk only works against development presently) | 
| 3.3.2 | 07/16/2021 | sso bug fixes | 
| 3.3.1 | 07/16/2021 | screen recording - event sub text used for assisting in UX rendering | 
| 3.3.0 | 07/16/2021 | new endpoint SingleSignOn | 
| 3.2.15 | 07/13/2021 | storefront communications - added methods to retrieve step dispatch logs | 
| 3.2.14 | 07/12/2021 | fix documentation bug on packing slip methods for order api | 
| 3.2.13 | 07/12/2021 | coupon api - added hideFromCustomer flag | 
| 3.2.12 | 07/09/2021 | new fulfillment and order methods for generation of packing slips | 
| 3.2.11 | 07/08/2021 | screen recording - missing external tracking flag added | 
| 3.2.10 | 07/08/2021 | customer profile - allow drop shipping options | 
| 3.2.9 | 07/07/2021 | screen recording - provide cost per thousand and retention interval | 
| 3.2.8 | 07/06/2021 | intgeration logs - min max log date/time retured in filter values | 
| 3.2.7 | 07/05/2021 | integration logger bug fixes | 
| 3.2.6 | 06/25/2021 | integration log: added logger name | 
| 3.2.2 | 06/24/2021 | integration log file mime type added | 
| 3.2.0 | 06/23/2021 | Changed 4 methods due to naming conflicts revealed through swagger validator.  All internal methods, so impact should be negligible | 
| 3.1.50 | 06/23/2021 | Integrated Logging: returning back streamed files for log requests | 
| 3.1.49 | 06/17/2021 | Integrated Logging: standardize the response object from getIntegrationLog method  | 
| 3.1.47 | 06/16/2021 | Integrated Logging Rest API  | 
| 3.1.46 | 06/14/2021 | Screen recording: server side paginated heat map index with url contains filters, Item: channel partner item mapping unit cost override  | 
| 3.1.44 | 06/02/2021 | new boolean flag on items object to allow sharing of reviews between items   | 
| 3.1.43 | 06/01/2021 | fix item serialized name of item serialized name for channel partner item mappings  | 
| 3.1.42 | 06/01/2021 | added quickbooks accounting codes at the tiered level for tiered coupons  | 
| 3.1.41 | 05/21/2021 | screen recording heatmap methods | 
| 3.1.40 | 05/20/2021 | Order.summary.actual_payment_processing field added | 
| 3.1.39 | 05/19/2021 | full deployment to ensure all language SDKs are up to date | 
| 3.1.37 | 05/18/2021 | removed php sdk dependency on ext-mbstring by generating sdk with polyfill requirement.  sdk is more portable now. | 
| 3.1.35 | 05/14/2021 | screen recording histogram data  | 
| 3.1.34 | 05/12/2021 | screen recording preferred language, last x days filter, referrer domain | 
| 3.1.33 | 05/11/2021 | creen recording filter for affiliate id and email | 
| 3.1.32 | 05/06/2021 | customer profile pending loyalty points  | 
| 3.1.31 | 05/06/2021 | Added email domian field to screen recordings for filtering  | 
| 3.1.30 | 04/27/2021 | OrderApi.processPayment now allows a specific amount to be billed  | 
| 3.1.29 | 04/26/2021 | screen recording language iso code | 
| 3.1.28 | 04/26/2021 | screen recording statistics on the setting object | 
| 3.1.27 | 04/20/2021 | bug fix - annotation misspell on new email campaign property |
| 3.1.26 | 04/20/2021 | StoreFront Connumications - flag to end campaign or flow once purchase happens anywhere |
| 3.1.25 | 04/19/2021 | Screen recording UTM campaign and source fields |
| 3.1.24 | 04/16/2021 | Screen recording aggregations on communications campaign/flows |
| 3.1.22 | 04/09/2021 | Move URL filter values into page level view for screen recordings |
| 3.1.18 | 03/17/2021 | Added order query by ship on date |
| 3.1.17 | 03/17/2021 | New coupon - percent off MSRP item |
| 3.1.16 | 03/16/2021 | screen recording filter page parameter names |
| 3.1.15 | 03/15/2021 | fix response from deleteScreenRecordingSegment that should have been void |
| 3.1.14 | 03/15/2021 | sort screen recordings by favorite flag |
| 3.1.13 | 03/02/2021 | new webhook order_payment_failed |
| 3.1.12 | 02/25/2021 | added screen recording visitor_first_seen property |
| 3.1.11 | 02/24/2021 | Added Screen recording visitor number |
| 3.1.10 | 02/24/2021 | Added Screen recording merchant notes |
| 3.1.9 | 02/24/2021 | Allow coupons to be configured as unique with expiration on cart step within StoreFront Communications |
| 3.1.8 | 02/24/2021 | Add flag: screen recording missing event boolean |
| 3.1.5 | 02/12/2021 | Bug Fix: PHP retry logic missing a closing brace. Also screen recording page view data response refactor |
| 3.1.3 | 02/11/2021 | Bug Fix: wrong return type on CustomerApi.validateEmailVerificationToken |
| 3.1.2 | 02/11/2021 | CustomerApi.getEmailVerificationToken, CustomerApi.validateEmailVerificationToken added to allow for custom email verification.  Also added favorite flag to screen recording object |
| 3.1.1 | 02/10/2021 | CustomerApi.getCustomerByEmail() method added |
| 3.1.0 | 02/10/2021 | Minor revision jump.  Added new convenience methods for simple_key use to all api calls.  Updated docs |
| 3.0.75 | 02/01/2021 | StoreFront Communication plan revision (internal use) |
| 3.0.71 | 01/28/2021 | BugFix: PHP SDK retry logic NPE |
| 3.0.70 | 01/26/2021 | Checkout return URL support |
| 3.0.66 | 01/22/2021 | code library attributes (mostly internal dev) |
| 3.0.65 | 01/22/2021 | Added folder support for email campaigns and flows |
| 3.0.64 | 01/20/2021 | Bug fix on revenue per customer field incorrectly named. |
| 3.0.63 | 01/20/2021 | CouponAPI: bug fixes and new method doesCouponCodeExist |
| 3.0.62 | 01/19/2021 | Added retry ability when rate limit is triggered (PHP SDK only) only) Other sdk to follow. |
| 3.0.60 | 01/14/2021 | Working with Ruby SDK |
| 3.0.57 | 12/17/2020 | CouponAPI: Added Buy one get one free coupon |
| 3.0.53 | 12/14/2020 | StoreFrontAPI: added a duplicate method to load the pricing tiers on the StoreFront |
| 3.0.51 | 12/09/2020 | UserAPI: internal bug preventing proper usage of user group creation |
| 3.0.45 | 12/03/2020 | CouponAPI: added partial searches to getCoupon params, added deleteCoupons method, fixed bugs |
| 3.0.44 | 12/03/2020 | Code library updates, intended for internal use |
| 3.0.43 | 12/02/2020 | Added fields to code library to handle versions of published items |
| 3.0.42 | 12/02/2020 | Added display values to CouponApi.getEditorValues to make type dropdowns easy |
| 3.0.41 | 11/17/2020 | New modify cart step option for StoreFront communications |
| 3.0.39 | 11/12/2020 | Added Customer.tax_codes.taxjar_exemption_type |
| 3.0.38 | 11/09/2020 | Added TaxProviderTaxJar.configuration.send_outside_nexus flag |
| 3.0.37 | 11/06/2020 | Added transactional email screenshots for code library |
| 3.0.36 | 11/03/2020 | Added missing constant for pre-order stage |
| 3.0.34 | 10/26/2020 | UserAPI initial release |
| 3.0.33 | 10/23/2020 | Added library_item_oid to StoreFront Communications email object for upcoming code library |
| 3.0.32 | 10/21/2020 | Added new StoreFrontApi.search method that takes a POST instead of a GET |
| 3.0.31 | 10/16/2020 | more dev work on code library (internal) |
| 3.0.30 | 10/08/2020 | development work on code library (internal), first version of UserAPI.  The UserAPI is not live yet. |
| 3.0.29 | 09/29/2020 | new boolean field on coupon: bug fix |
| 3.0.28 | 09/29/2020 | new boolean field on coupon: free item with purchase of another item |
| 3.0.27 | 09/29/2020 | Refactored the code library applyToStoreFront to provide support for marketing emails |
| 3.0.26 | 09/25/2020 | Expose actual shipping and fulfillment costs in the order summary object |
| 3.0.25 | 09/16/2020 | New method: OrderApi.adjustOrderTotal |
| 3.0.24 | 09/10/2020 | Bugfix: incorrect response type on CheckoutAPI.registerAffiliateClick |
| 3.0.23 | 09/02/2020 | Added flag to email plan object.  allow_tracking_emails |
| 3.0.22 | 09/02/2020 | Order object - added tracking details |
| 3.0.21 | 09/01/2020 | break fix in php sdk due to bad namespace |
| 3.0.20 | 09/01/2020 | Added OrderApi.processPayment method |
| 3.0.19 | 08/28/2020 | Code Library development: added kraken parameters for thumbnail image generation. |
| 3.0.17 | 08/26/2020 | cont. development work on Code Library |
| 3.0.14 | 08/19/2020 | development work on Code Library |
| 3.0.13 | 08/18/2020 | development work on Code Library |
| 3.0.12 | 08/13/2020 | screenshot urls for campaigns and flows (storefront communications) |
| 3.0.11 | 08/12/2020 | Refactoring and development for Code Library (not released yet) |
| 3.0.10 | 08/10/2020 | Method for registering an affliate click via the SDK, found within CheckoutAPI |
| 3.0.8 | 08/05/2020 | stub for code library 'getLibraryFilterValues' for populating drop down lists |
| 3.0.4 | 08/05/2020 | fixed misspell of 'version' in LibraryItem object. |
| 3.0.3 | 08/04/2020 | added description to addToLibrary call to allow for initial description |
| 3.0.2 | 08/03/2020 | added option on email render step config to allow override of subject, added flow/campaign flag to end once customer purchases |
| 3.0.1 | 07/27/2020 | added init_json to storefront communication email objects |
| 3.0.0 | 07/01/2020 | upgraded our swagger-codegen fork to the latest swagger source code. this was a major changes so we jumped version numbers.  please test all code. |

Some changes jump version numbers due to multiple commits for bug fixes, omissions, and errors.
At UltraCart, we eat our own dog food, and we increment the version number for every commit in order
to generate a new javascript npm.  For this reason, version gaps will be found in the change log above.
